{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Detect Variants workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "record",
                            "name": "#vep_custom_annotation.yml/vep_custom_annotation",
                            "label": "custom annotation file to be used by vep",
                            "fields": [
                                {
                                    "type": {
                                        "type": "record",
                                        "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info",
                                        "fields": [
                                            {
                                                "type": "boolean",
                                                "label": "Identify known variants colocated with input variant",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/check_existing"
                                            },
                                            {
                                                "type": {
                                                    "type": "enum",
                                                    "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format",
                                                    "symbols": [
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/bed",
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/gff",
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/gtf",
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/vcf",
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/bigwig"
                                                    ],
                                                    "label": "Annotation file type"
                                                },
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format"
                                            },
                                            {
                                                "type": "File",
                                                "label": "File to be used for annotation, include index file",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/file"
                                            },
                                            {
                                                "type": [
                                                    "null",
                                                    "boolean"
                                                ],
                                                "label": "Use this annotation for gnomad filtering?",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/gnomad_filter"
                                            },
                                            {
                                                "type": "string",
                                                "label": "Used as key for new VEP annotation",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/name"
                                            },
                                            {
                                                "type": [
                                                    "null",
                                                    {
                                                        "type": "array",
                                                        "items": "string"
                                                    }
                                                ],
                                                "label": "List of VCF fields to annotate",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/vcf_fields"
                                            }
                                        ]
                                    },
                                    "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation"
                                },
                                {
                                    "type": "boolean",
                                    "label": "Force report the overlapping coordinates of custom feature instead of based on the exact coordinates",
                                    "name": "#vep_custom_annotation.yml/vep_custom_annotation/force_report_coordinates"
                                },
                                {
                                    "type": [
                                        {
                                            "type": "enum",
                                            "symbols": [
                                                "#vep_custom_annotation.yml/vep_custom_annotation/method/exact",
                                                "#vep_custom_annotation.yml/vep_custom_annotation/method/overlap"
                                            ],
                                            "label": "Require exact or overlap to annotate variants"
                                        }
                                    ],
                                    "name": "#vep_custom_annotation.yml/vep_custom_annotation/method"
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/annotate_coding_only"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "id": "#main/cle_vcf_filter"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/docm_vcf"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "id": "#main/filter_docm_variants"
                },
                {
                    "type": "float",
                    "default": 0.001,
                    "id": "#main/filter_gnomADe_maximum_population_allele_frequency"
                },
                {
                    "type": "float",
                    "default": 0.15,
                    "id": "#main/filter_mapq0_threshold"
                },
                {
                    "type": "int",
                    "default": 1,
                    "id": "#main/filter_minimum_depth"
                },
                {
                    "type": "float",
                    "default": 5,
                    "id": "#main/filter_somatic_llr_threshold"
                },
                {
                    "type": "File",
                    "id": "#main/interval_list"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "doc": "Previously discovered variants to be flagged in this pipelines's output vcf",
                    "id": "#main/known_variants"
                },
                {
                    "type": "int",
                    "default": 50,
                    "id": "#main/mutect_scatter_count"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#main/normal_bam"
                },
                {
                    "type": "string",
                    "id": "#main/normal_sample_name"
                },
                {
                    "type": "int",
                    "default": 400,
                    "id": "#main/pindel_insert_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/readcount_minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/readcount_minimum_mapping_quality"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#main/strelka_cpu_reserved"
                },
                {
                    "type": "boolean",
                    "id": "#main/strelka_exome_mode"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/synonyms_file"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#main/tumor_bam"
                },
                {
                    "type": "string",
                    "id": "#main/tumor_sample_name"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "CHROM",
                        "POS",
                        "ID",
                        "REF",
                        "ALT",
                        "set",
                        "AC",
                        "AF"
                    ],
                    "id": "#main/variants_to_table_fields"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "GT",
                        "AD"
                    ],
                    "id": "#main/variants_to_table_genotype_fields"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#main/varscan_max_normal_freq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#main/varscan_min_coverage"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "id": "#main/varscan_min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "id": "#main/varscan_p_value"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#main/varscan_strand_filter"
                },
                {
                    "type": [
                        "string",
                        "Directory"
                    ],
                    "id": "#main/vep_cache_dir"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#vep_custom_annotation.yml/vep_custom_annotation"
                    },
                    "doc": "custom type, check types directory for input format",
                    "id": "#main/vep_custom_annotations"
                },
                {
                    "type": "string",
                    "doc": "genome assembly to use in vep. Examples: GRCh38 or GRCm38",
                    "id": "#main/vep_ensembl_assembly"
                },
                {
                    "type": "string",
                    "doc": "ensembl species - Must be present in the cache directory. Examples: homo_sapiens or mus_musculus",
                    "id": "#main/vep_ensembl_species"
                },
                {
                    "type": "string",
                    "doc": "ensembl version - Must be present in the cache directory. Example: 95",
                    "id": "#main/vep_ensembl_version"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/vep_pick/pick",
                                "#main/vep_pick/flag_pick",
                                "#main/vep_pick/pick_allele",
                                "#main/vep_pick/per_gene",
                                "#main/vep_pick/pick_allele_gene",
                                "#main/vep_pick/flag_pick_allele",
                                "#main/vep_pick/flag_pick_allele_gene"
                            ]
                        }
                    ],
                    "id": "#main/vep_pick"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "Downstream",
                        "Wildtype"
                    ],
                    "id": "#main/vep_plugins"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "HGVSc",
                        "HGVSp"
                    ],
                    "id": "#main/vep_to_table_fields"
                }
            ],
            "steps": [
                {
                    "run": "#docm_add_variants.cwl",
                    "in": [
                        {
                            "source": "#main/combine/combined_vcf",
                            "id": "#main/add_docm_variants/callers_vcf"
                        },
                        {
                            "source": "#main/docm/docm_variants_vcf",
                            "id": "#main/add_docm_variants/docm_vcf"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/add_docm_variants/reference"
                        }
                    ],
                    "out": [
                        "#main/add_docm_variants/merged_vcf"
                    ],
                    "id": "#main/add_docm_variants"
                },
                {
                    "run": "#vcf_readcount_annotator.cwl",
                    "in": [
                        {
                            "default": "DNA",
                            "id": "#main/add_normal_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "source": "#main/normal_bam_readcount/indel_bam_readcount_tsv",
                            "id": "#main/add_normal_bam_readcount_to_vcf/indel_bam_readcount_tsv"
                        },
                        {
                            "source": "#main/normal_sample_name",
                            "id": "#main/add_normal_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "source": "#main/normal_bam_readcount/snv_bam_readcount_tsv",
                            "id": "#main/add_normal_bam_readcount_to_vcf/snv_bam_readcount_tsv"
                        },
                        {
                            "source": "#main/add_tumor_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                            "id": "#main/add_normal_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/add_normal_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#main/add_normal_bam_readcount_to_vcf"
                },
                {
                    "run": "#vcf_readcount_annotator.cwl",
                    "in": [
                        {
                            "default": "DNA",
                            "id": "#main/add_tumor_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "source": "#main/tumor_bam_readcount/indel_bam_readcount_tsv",
                            "id": "#main/add_tumor_bam_readcount_to_vcf/indel_bam_readcount_tsv"
                        },
                        {
                            "source": "#main/tumor_sample_name",
                            "id": "#main/add_tumor_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "source": "#main/tumor_bam_readcount/snv_bam_readcount_tsv",
                            "id": "#main/add_tumor_bam_readcount_to_vcf/snv_bam_readcount_tsv"
                        },
                        {
                            "source": "#main/annotate_variants/annotated_vcf",
                            "id": "#main/add_tumor_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/add_tumor_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#main/add_tumor_bam_readcount_to_vcf"
                },
                {
                    "run": "#add_vep_fields_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/variants_to_table/variants_tsv",
                            "id": "#main/add_vep_fields_to_table/tsv"
                        },
                        {
                            "source": "#main/annotated_filter_index/indexed_vcf",
                            "id": "#main/add_vep_fields_to_table/vcf"
                        },
                        {
                            "source": "#main/vep_to_table_fields",
                            "id": "#main/add_vep_fields_to_table/vep_fields"
                        }
                    ],
                    "out": [
                        "#main/add_vep_fields_to_table/annotated_variants_tsv"
                    ],
                    "id": "#main/add_vep_fields_to_table"
                },
                {
                    "run": "#vep.cwl",
                    "in": [
                        {
                            "source": "#main/vep_cache_dir",
                            "id": "#main/annotate_variants/cache_dir"
                        },
                        {
                            "source": "#main/annotate_coding_only",
                            "id": "#main/annotate_variants/coding_only"
                        },
                        {
                            "source": "#main/vep_custom_annotations",
                            "id": "#main/annotate_variants/custom_annotations"
                        },
                        {
                            "source": "#main/vep_ensembl_assembly",
                            "id": "#main/annotate_variants/ensembl_assembly"
                        },
                        {
                            "source": "#main/vep_ensembl_species",
                            "id": "#main/annotate_variants/ensembl_species"
                        },
                        {
                            "source": "#main/vep_ensembl_version",
                            "id": "#main/annotate_variants/ensembl_version"
                        },
                        {
                            "source": "#main/vep_pick",
                            "id": "#main/annotate_variants/pick"
                        },
                        {
                            "source": "#main/vep_plugins",
                            "id": "#main/annotate_variants/plugins"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/annotate_variants/reference"
                        },
                        {
                            "source": "#main/synonyms_file",
                            "id": "#main/annotate_variants/synonyms_file"
                        },
                        {
                            "source": "#main/decompose_index/indexed_vcf",
                            "id": "#main/annotate_variants/vcf"
                        }
                    ],
                    "out": [
                        "#main/annotate_variants/annotated_vcf",
                        "#main/annotate_variants/vep_summary"
                    ],
                    "id": "#main/annotate_variants"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#main/filter_vcf/filtered_vcf",
                            "id": "#main/annotated_filter_bgzip/file"
                        }
                    ],
                    "out": [
                        "#main/annotated_filter_bgzip/bgzipped_file"
                    ],
                    "id": "#main/annotated_filter_bgzip"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/annotated_filter_bgzip/bgzipped_file",
                            "id": "#main/annotated_filter_index/vcf"
                        }
                    ],
                    "out": [
                        "#main/annotated_filter_index/indexed_vcf"
                    ],
                    "id": "#main/annotated_filter_index"
                },
                {
                    "run": "#combine_variants.cwl",
                    "in": [
                        {
                            "source": "#main/mutect/filtered_vcf",
                            "id": "#main/combine/mutect_vcf"
                        },
                        {
                            "source": "#main/pindel/filtered_vcf",
                            "id": "#main/combine/pindel_vcf"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/combine/reference"
                        },
                        {
                            "source": "#main/strelka/filtered_vcf",
                            "id": "#main/combine/strelka_vcf"
                        },
                        {
                            "source": "#main/varscan/filtered_vcf",
                            "id": "#main/combine/varscan_vcf"
                        }
                    ],
                    "out": [
                        "#main/combine/combined_vcf"
                    ],
                    "id": "#main/combine"
                },
                {
                    "run": "#vt_decompose.cwl",
                    "in": [
                        {
                            "source": "#main/add_docm_variants/merged_vcf",
                            "id": "#main/decompose/vcf"
                        }
                    ],
                    "out": [
                        "#main/decompose/decomposed_vcf"
                    ],
                    "id": "#main/decompose"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/decompose/decomposed_vcf",
                            "id": "#main/decompose_index/vcf"
                        }
                    ],
                    "out": [
                        "#main/decompose_index/indexed_vcf"
                    ],
                    "id": "#main/decompose_index"
                },
                {
                    "run": "#docm_cle.cwl",
                    "in": [
                        {
                            "source": "#main/docm_vcf",
                            "id": "#main/docm/docm_vcf"
                        },
                        {
                            "source": "#main/filter_docm_variants",
                            "id": "#main/docm/filter_docm_variants"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/docm/interval_list"
                        },
                        {
                            "source": "#main/normal_bam",
                            "id": "#main/docm/normal_bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/docm/reference"
                        },
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/docm/tumor_bam"
                        }
                    ],
                    "out": [
                        "#main/docm/docm_variants_vcf"
                    ],
                    "id": "#main/docm"
                },
                {
                    "run": "#filter_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/cle_vcf_filter",
                            "id": "#main/filter_vcf/do_cle_vcf_filter"
                        },
                        {
                            "source": "#main/filter_gnomADe_maximum_population_allele_frequency",
                            "id": "#main/filter_vcf/filter_gnomADe_maximum_population_allele_frequency"
                        },
                        {
                            "source": "#main/filter_mapq0_threshold",
                            "id": "#main/filter_vcf/filter_mapq0_threshold"
                        },
                        {
                            "source": "#main/filter_minimum_depth",
                            "id": "#main/filter_vcf/filter_minimum_depth"
                        },
                        {
                            "source": "#main/filter_somatic_llr_threshold",
                            "id": "#main/filter_vcf/filter_somatic_llr_threshold"
                        },
                        {
                            "source": "#main/vep_custom_annotations",
                            "valueFrom": "${\n   if(self){\n        for(var i=0; i<self.length; i++){\n            if(self[i].annotation.gnomad_filter){\n                return(self[i].annotation.name + '_AF');\n            }\n        }\n    }\n    return('gnomAD_AF');\n}\n",
                            "id": "#main/filter_vcf/gnomad_field_name"
                        },
                        {
                            "source": "#main/known_variants",
                            "id": "#main/filter_vcf/known_variants"
                        },
                        {
                            "source": "#main/normal_sample_name",
                            "id": "#main/filter_vcf/normal_sample_name"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/filter_vcf/reference"
                        },
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/filter_vcf/tumor_bam"
                        },
                        {
                            "source": "#main/tumor_sample_name",
                            "id": "#main/filter_vcf/tumor_sample_name"
                        },
                        {
                            "source": "#main/index/indexed_vcf",
                            "id": "#main/filter_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_vcf/filtered_vcf"
                    ],
                    "id": "#main/filter_vcf"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/add_normal_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                            "id": "#main/index/vcf"
                        }
                    ],
                    "out": [
                        "#main/index/indexed_vcf"
                    ],
                    "id": "#main/index"
                },
                {
                    "run": "#mutect.cwl",
                    "in": [
                        {
                            "source": "#main/interval_list",
                            "id": "#main/mutect/interval_list"
                        },
                        {
                            "source": "#main/normal_bam",
                            "id": "#main/mutect/normal_bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/mutect/reference"
                        },
                        {
                            "source": "#main/mutect_scatter_count",
                            "id": "#main/mutect/scatter_count"
                        },
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/mutect/tumor_bam"
                        },
                        {
                            "source": "#main/tumor_sample_name",
                            "id": "#main/mutect/tumor_sample_name"
                        }
                    ],
                    "out": [
                        "#main/mutect/unfiltered_vcf",
                        "#main/mutect/filtered_vcf"
                    ],
                    "id": "#main/mutect"
                },
                {
                    "run": "#bam_readcount.cwl",
                    "in": [
                        {
                            "source": "#main/normal_bam",
                            "id": "#main/normal_bam_readcount/bam"
                        },
                        {
                            "source": "#main/readcount_minimum_base_quality",
                            "id": "#main/normal_bam_readcount/min_base_quality"
                        },
                        {
                            "source": "#main/readcount_minimum_mapping_quality",
                            "id": "#main/normal_bam_readcount/min_mapping_quality"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/normal_bam_readcount/reference_fasta"
                        },
                        {
                            "source": "#main/normal_sample_name",
                            "id": "#main/normal_bam_readcount/sample"
                        },
                        {
                            "source": "#main/annotate_variants/annotated_vcf",
                            "id": "#main/normal_bam_readcount/vcf"
                        }
                    ],
                    "out": [
                        "#main/normal_bam_readcount/snv_bam_readcount_tsv",
                        "#main/normal_bam_readcount/indel_bam_readcount_tsv"
                    ],
                    "id": "#main/normal_bam_readcount"
                },
                {
                    "run": "#pindel.cwl",
                    "in": [
                        {
                            "source": "#main/pindel_insert_size",
                            "id": "#main/pindel/insert_size"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/pindel/interval_list"
                        },
                        {
                            "source": "#main/normal_bam",
                            "id": "#main/pindel/normal_bam"
                        },
                        {
                            "source": "#main/normal_sample_name",
                            "id": "#main/pindel/normal_sample_name"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/pindel/reference"
                        },
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/pindel/tumor_bam"
                        },
                        {
                            "source": "#main/tumor_sample_name",
                            "id": "#main/pindel/tumor_sample_name"
                        }
                    ],
                    "out": [
                        "#main/pindel/unfiltered_vcf",
                        "#main/pindel/filtered_vcf"
                    ],
                    "id": "#main/pindel"
                },
                {
                    "run": "#strelka_and_post_processing.cwl",
                    "in": [
                        {
                            "source": "#main/strelka_cpu_reserved",
                            "id": "#main/strelka/cpu_reserved"
                        },
                        {
                            "source": "#main/strelka_exome_mode",
                            "id": "#main/strelka/exome_mode"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/strelka/interval_list"
                        },
                        {
                            "source": "#main/normal_bam",
                            "id": "#main/strelka/normal_bam"
                        },
                        {
                            "source": "#main/normal_sample_name",
                            "id": "#main/strelka/normal_sample_name"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/strelka/reference"
                        },
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/strelka/tumor_bam"
                        },
                        {
                            "source": "#main/tumor_sample_name",
                            "id": "#main/strelka/tumor_sample_name"
                        }
                    ],
                    "out": [
                        "#main/strelka/unfiltered_vcf",
                        "#main/strelka/filtered_vcf"
                    ],
                    "id": "#main/strelka"
                },
                {
                    "run": "#bam_readcount.cwl",
                    "in": [
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/tumor_bam_readcount/bam"
                        },
                        {
                            "source": "#main/readcount_minimum_base_quality",
                            "id": "#main/tumor_bam_readcount/min_base_quality"
                        },
                        {
                            "source": "#main/readcount_minimum_mapping_quality",
                            "id": "#main/tumor_bam_readcount/min_mapping_quality"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/tumor_bam_readcount/reference_fasta"
                        },
                        {
                            "source": "#main/tumor_sample_name",
                            "id": "#main/tumor_bam_readcount/sample"
                        },
                        {
                            "source": "#main/annotate_variants/annotated_vcf",
                            "id": "#main/tumor_bam_readcount/vcf"
                        }
                    ],
                    "out": [
                        "#main/tumor_bam_readcount/snv_bam_readcount_tsv",
                        "#main/tumor_bam_readcount/indel_bam_readcount_tsv"
                    ],
                    "id": "#main/tumor_bam_readcount"
                },
                {
                    "run": "#variants_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/variants_to_table_fields",
                            "id": "#main/variants_to_table/fields"
                        },
                        {
                            "source": "#main/variants_to_table_genotype_fields",
                            "id": "#main/variants_to_table/genotype_fields"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/variants_to_table/reference"
                        },
                        {
                            "source": "#main/annotated_filter_index/indexed_vcf",
                            "id": "#main/variants_to_table/vcf"
                        }
                    ],
                    "out": [
                        "#main/variants_to_table/variants_tsv"
                    ],
                    "id": "#main/variants_to_table"
                },
                {
                    "run": "#varscan_pre_and_post_processing.cwl",
                    "in": [
                        {
                            "source": "#main/interval_list",
                            "id": "#main/varscan/interval_list"
                        },
                        {
                            "source": "#main/varscan_max_normal_freq",
                            "id": "#main/varscan/max_normal_freq"
                        },
                        {
                            "source": "#main/varscan_min_coverage",
                            "id": "#main/varscan/min_coverage"
                        },
                        {
                            "source": "#main/varscan_min_var_freq",
                            "id": "#main/varscan/min_var_freq"
                        },
                        {
                            "source": "#main/normal_bam",
                            "id": "#main/varscan/normal_bam"
                        },
                        {
                            "source": "#main/normal_sample_name",
                            "id": "#main/varscan/normal_sample_name"
                        },
                        {
                            "source": "#main/varscan_p_value",
                            "id": "#main/varscan/p_value"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/varscan/reference"
                        },
                        {
                            "source": "#main/varscan_strand_filter",
                            "id": "#main/varscan/strand_filter"
                        },
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/varscan/tumor_bam"
                        },
                        {
                            "source": "#main/tumor_sample_name",
                            "id": "#main/varscan/tumor_sample_name"
                        }
                    ],
                    "out": [
                        "#main/varscan/unfiltered_vcf",
                        "#main/varscan/filtered_vcf"
                    ],
                    "id": "#main/varscan"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/docm/docm_variants_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/docm_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/annotated_filter_index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/final_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/add_vep_fields_to_table/annotated_variants_tsv",
                    "id": "#main/final_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/final_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/mutect/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/mutect_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/mutect/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/mutect_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/normal_bam_readcount/indel_bam_readcount_tsv",
                    "id": "#main/normal_indel_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/normal_bam_readcount/snv_bam_readcount_tsv",
                    "id": "#main/normal_snv_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/pindel/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/pindel_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/pindel/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/pindel_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/strelka/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/strelka_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/strelka/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/strelka_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/tumor_bam_readcount/indel_bam_readcount_tsv",
                    "id": "#main/tumor_indel_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/tumor_bam_readcount/snv_bam_readcount_tsv",
                    "id": "#main/tumor_snv_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/varscan/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/varscan_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/varscan/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/varscan_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/annotate_variants/vep_summary",
                    "id": "#main/vep_summary"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "bgzip and index VCF",
            "inputs": [
                {
                    "type": "File",
                    "id": "#bgzip_and_index.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bgzip_and_index.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bgzip_and_index.cwl/indexed_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/vcf",
                            "id": "#bgzip_and_index.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#bgzip_and_index.cwl/bgzip"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/bgzip/bgzipped_file",
                            "id": "#bgzip_and_index.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/index/indexed_vcf"
                    ],
                    "id": "#bgzip_and_index.cwl/index"
                }
            ],
            "id": "#bgzip_and_index.cwl"
        },
        {
            "class": "Workflow",
            "label": "Detect Docm variants",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#docm_cle.cwl/docm_vcf"
                },
                {
                    "type": "boolean",
                    "id": "#docm_cle.cwl/filter_docm_variants"
                },
                {
                    "type": "File",
                    "id": "#docm_cle.cwl/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#docm_cle.cwl/normal_bam"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#docm_cle.cwl/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#docm_cle.cwl/tumor_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#docm_cle.cwl/index2/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#docm_cle.cwl/docm_variants_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#docm_gatk_haplotype_caller.cwl",
                    "in": [
                        {
                            "source": "#docm_cle.cwl/tumor_bam",
                            "id": "#docm_cle.cwl/GATK_haplotype_caller/bam"
                        },
                        {
                            "source": "#docm_cle.cwl/docm_vcf",
                            "id": "#docm_cle.cwl/GATK_haplotype_caller/docm_vcf"
                        },
                        {
                            "source": "#docm_cle.cwl/interval_list",
                            "id": "#docm_cle.cwl/GATK_haplotype_caller/interval_list"
                        },
                        {
                            "source": "#docm_cle.cwl/normal_bam",
                            "id": "#docm_cle.cwl/GATK_haplotype_caller/normal_bam"
                        },
                        {
                            "source": "#docm_cle.cwl/reference",
                            "id": "#docm_cle.cwl/GATK_haplotype_caller/reference"
                        }
                    ],
                    "out": [
                        "#docm_cle.cwl/GATK_haplotype_caller/docm_raw_variants"
                    ],
                    "id": "#docm_cle.cwl/GATK_haplotype_caller"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#docm_cle.cwl/GATK_haplotype_caller/docm_raw_variants",
                            "id": "#docm_cle.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#docm_cle.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#docm_cle.cwl/bgzip"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#docm_cle.cwl/docm_filter/docm_filtered_variants",
                            "id": "#docm_cle.cwl/bgzip2/file"
                        }
                    ],
                    "out": [
                        "#docm_cle.cwl/bgzip2/bgzipped_file"
                    ],
                    "id": "#docm_cle.cwl/bgzip2"
                },
                {
                    "run": "#vt_decompose.cwl",
                    "in": [
                        {
                            "source": "#docm_cle.cwl/index/indexed_vcf",
                            "id": "#docm_cle.cwl/decompose/vcf"
                        }
                    ],
                    "out": [
                        "#docm_cle.cwl/decompose/decomposed_vcf"
                    ],
                    "id": "#docm_cle.cwl/decompose"
                },
                {
                    "run": "#filter_vcf_docm.cwl",
                    "in": [
                        {
                            "source": "#docm_cle.cwl/decompose/decomposed_vcf",
                            "id": "#docm_cle.cwl/docm_filter/docm_raw_variants"
                        },
                        {
                            "source": "#docm_cle.cwl/filter_docm_variants",
                            "id": "#docm_cle.cwl/docm_filter/filter_docm_variants"
                        },
                        {
                            "source": "#docm_cle.cwl/normal_bam",
                            "id": "#docm_cle.cwl/docm_filter/normal_bam"
                        },
                        {
                            "source": "#docm_cle.cwl/tumor_bam",
                            "id": "#docm_cle.cwl/docm_filter/tumor_bam"
                        }
                    ],
                    "out": [
                        "#docm_cle.cwl/docm_filter/docm_filtered_variants"
                    ],
                    "id": "#docm_cle.cwl/docm_filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#docm_cle.cwl/bgzip/bgzipped_file",
                            "id": "#docm_cle.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#docm_cle.cwl/index/indexed_vcf"
                    ],
                    "id": "#docm_cle.cwl/index"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#docm_cle.cwl/bgzip2/bgzipped_file",
                            "id": "#docm_cle.cwl/index2/vcf"
                        }
                    ],
                    "out": [
                        "#docm_cle.cwl/index2/indexed_vcf"
                    ],
                    "id": "#docm_cle.cwl/index2"
                }
            ],
            "id": "#docm_cle.cwl"
        },
        {
            "class": "Workflow",
            "label": "Apply filters to VCF file",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "id": "#filter_vcf.cwl/do_cle_vcf_filter"
                },
                {
                    "type": "float",
                    "id": "#filter_vcf.cwl/filter_gnomADe_maximum_population_allele_frequency"
                },
                {
                    "type": "float",
                    "id": "#filter_vcf.cwl/filter_mapq0_threshold"
                },
                {
                    "type": "int",
                    "id": "#filter_vcf.cwl/filter_minimum_depth"
                },
                {
                    "type": "float",
                    "id": "#filter_vcf.cwl/filter_somatic_llr_threshold"
                },
                {
                    "type": "string",
                    "id": "#filter_vcf.cwl/gnomad_field_name"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "doc": "Previously discovered variants to be flagged in this workflow's output vcf",
                    "id": "#filter_vcf.cwl/known_variants"
                },
                {
                    "type": "string",
                    "id": "#filter_vcf.cwl/normal_sample_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#filter_vcf.cwl/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#filter_vcf.cwl/tumor_bam"
                },
                {
                    "type": "string",
                    "id": "#filter_vcf.cwl/tumor_sample_name"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#filter_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#filter_vcf.cwl/set_final_vcf_name/replacement",
                    "id": "#filter_vcf.cwl/filtered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#filter_known_variants.cwl",
                    "in": [
                        {
                            "source": "#filter_vcf.cwl/known_variants",
                            "id": "#filter_vcf.cwl/filter_known_variants/known_variants"
                        },
                        {
                            "source": "#filter_vcf.cwl/vcf",
                            "id": "#filter_vcf.cwl/filter_known_variants/vcf"
                        }
                    ],
                    "out": [
                        "#filter_vcf.cwl/filter_known_variants/known_filtered"
                    ],
                    "id": "#filter_vcf.cwl/filter_known_variants"
                },
                {
                    "run": "#filter_vcf_cle.cwl",
                    "in": [
                        {
                            "source": "#filter_vcf.cwl/do_cle_vcf_filter",
                            "id": "#filter_vcf.cwl/filter_vcf_cle/filter"
                        },
                        {
                            "source": "#filter_vcf.cwl/filter_vcf_mapq0/mapq0_filtered_vcf",
                            "id": "#filter_vcf.cwl/filter_vcf_cle/vcf"
                        }
                    ],
                    "out": [
                        "#filter_vcf.cwl/filter_vcf_cle/cle_filtered_vcf"
                    ],
                    "id": "#filter_vcf.cwl/filter_vcf_cle"
                },
                {
                    "run": "#filter_vcf_depth.cwl",
                    "in": [
                        {
                            "source": "#filter_vcf.cwl/filter_minimum_depth",
                            "id": "#filter_vcf.cwl/filter_vcf_depth/minimum_depth"
                        },
                        {
                            "source": [
                                "#filter_vcf.cwl/normal_sample_name",
                                "#filter_vcf.cwl/tumor_sample_name"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#filter_vcf.cwl/filter_vcf_depth/sample_names"
                        },
                        {
                            "source": "#filter_vcf.cwl/filter_vcf_cle/cle_filtered_vcf",
                            "id": "#filter_vcf.cwl/filter_vcf_depth/vcf"
                        }
                    ],
                    "out": [
                        "#filter_vcf.cwl/filter_vcf_depth/depth_filtered_vcf"
                    ],
                    "id": "#filter_vcf.cwl/filter_vcf_depth"
                },
                {
                    "run": "#filter_vcf_custom_allele_freq.cwl",
                    "in": [
                        {
                            "source": "#filter_vcf.cwl/gnomad_field_name",
                            "id": "#filter_vcf.cwl/filter_vcf_gnomADe_allele_freq/field_name"
                        },
                        {
                            "source": "#filter_vcf.cwl/filter_gnomADe_maximum_population_allele_frequency",
                            "id": "#filter_vcf.cwl/filter_vcf_gnomADe_allele_freq/maximum_population_allele_frequency"
                        },
                        {
                            "source": "#filter_vcf.cwl/filter_known_variants/known_filtered",
                            "id": "#filter_vcf.cwl/filter_vcf_gnomADe_allele_freq/vcf"
                        }
                    ],
                    "out": [
                        "#filter_vcf.cwl/filter_vcf_gnomADe_allele_freq/filtered_vcf"
                    ],
                    "id": "#filter_vcf.cwl/filter_vcf_gnomADe_allele_freq"
                },
                {
                    "run": "#filter_vcf_mapq0.cwl",
                    "in": [
                        {
                            "source": "#filter_vcf.cwl/reference",
                            "id": "#filter_vcf.cwl/filter_vcf_mapq0/reference"
                        },
                        {
                            "source": "#filter_vcf.cwl/filter_mapq0_threshold",
                            "id": "#filter_vcf.cwl/filter_vcf_mapq0/threshold"
                        },
                        {
                            "source": "#filter_vcf.cwl/tumor_bam",
                            "id": "#filter_vcf.cwl/filter_vcf_mapq0/tumor_bam"
                        },
                        {
                            "source": "#filter_vcf.cwl/filter_vcf_gnomADe_allele_freq/filtered_vcf",
                            "id": "#filter_vcf.cwl/filter_vcf_mapq0/vcf"
                        }
                    ],
                    "out": [
                        "#filter_vcf.cwl/filter_vcf_mapq0/mapq0_filtered_vcf"
                    ],
                    "id": "#filter_vcf.cwl/filter_vcf_mapq0"
                },
                {
                    "run": "#filter_vcf_somatic_llr.cwl",
                    "in": [
                        {
                            "source": "#filter_vcf.cwl/normal_sample_name",
                            "id": "#filter_vcf.cwl/filter_vcf_somatic_llr/normal_sample_name"
                        },
                        {
                            "source": "#filter_vcf.cwl/filter_somatic_llr_threshold",
                            "id": "#filter_vcf.cwl/filter_vcf_somatic_llr/threshold"
                        },
                        {
                            "source": "#filter_vcf.cwl/tumor_sample_name",
                            "id": "#filter_vcf.cwl/filter_vcf_somatic_llr/tumor_sample_name"
                        },
                        {
                            "source": "#filter_vcf.cwl/filter_vcf_depth/depth_filtered_vcf",
                            "id": "#filter_vcf.cwl/filter_vcf_somatic_llr/vcf"
                        }
                    ],
                    "out": [
                        "#filter_vcf.cwl/filter_vcf_somatic_llr/somatic_llr_filtered_vcf"
                    ],
                    "id": "#filter_vcf.cwl/filter_vcf_somatic_llr"
                },
                {
                    "run": "#staged_rename.cwl",
                    "in": [
                        {
                            "valueFrom": "annotated_filtered.vcf",
                            "id": "#filter_vcf.cwl/set_final_vcf_name/name"
                        },
                        {
                            "source": "#filter_vcf.cwl/filter_vcf_somatic_llr/somatic_llr_filtered_vcf",
                            "id": "#filter_vcf.cwl/set_final_vcf_name/original"
                        }
                    ],
                    "out": [
                        "#filter_vcf.cwl/set_final_vcf_name/replacement"
                    ],
                    "id": "#filter_vcf.cwl/set_final_vcf_name"
                }
            ],
            "id": "#filter_vcf.cwl"
        },
        {
            "class": "Workflow",
            "label": "fp_filter workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#fp_filter.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#fp_filter.cwl/min_var_freq"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#fp_filter.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#fp_filter.cwl/sample_name"
                },
                {
                    "type": "string",
                    "id": "#fp_filter.cwl/variant_caller"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#fp_filter.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#fp_filter.cwl/hard_filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#fp_filter.cwl/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#fp_filter.cwl/fp_index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#fp_filter.cwl/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#vt_decompose.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/normalize_variants/normalized_vcf",
                            "id": "#fp_filter.cwl/decompose_variants/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/decompose_variants/decomposed_vcf"
                    ],
                    "id": "#fp_filter.cwl/decompose_variants"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/fp_filter/filtered_vcf",
                            "id": "#fp_filter.cwl/fp_bgzip/file"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/fp_bgzip/bgzipped_file"
                    ],
                    "id": "#fp_filter.cwl/fp_bgzip"
                },
                {
                    "run": "#fp_filter.cwl_2",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/bam",
                            "id": "#fp_filter.cwl/fp_filter/bam"
                        },
                        {
                            "source": "#fp_filter.cwl/min_var_freq",
                            "id": "#fp_filter.cwl/fp_filter/min_var_freq"
                        },
                        {
                            "source": "#fp_filter.cwl/variant_caller",
                            "valueFrom": "$(self)_full",
                            "id": "#fp_filter.cwl/fp_filter/output_vcf_basename"
                        },
                        {
                            "source": "#fp_filter.cwl/reference",
                            "id": "#fp_filter.cwl/fp_filter/reference"
                        },
                        {
                            "source": "#fp_filter.cwl/sample_name",
                            "id": "#fp_filter.cwl/fp_filter/sample_name"
                        },
                        {
                            "source": "#fp_filter.cwl/index/indexed_vcf",
                            "id": "#fp_filter.cwl/fp_filter/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/fp_filter/filtered_vcf"
                    ],
                    "id": "#fp_filter.cwl/fp_filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/fp_bgzip/bgzipped_file",
                            "id": "#fp_filter.cwl/fp_index/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/fp_index/indexed_vcf"
                    ],
                    "id": "#fp_filter.cwl/fp_index"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#fp_filter.cwl/hard_filter/exclude_filtered"
                        },
                        {
                            "source": "#fp_filter.cwl/variant_caller",
                            "valueFrom": "$(self)_filtered",
                            "id": "#fp_filter.cwl/hard_filter/output_vcf_basename"
                        },
                        {
                            "source": "#fp_filter.cwl/reference",
                            "id": "#fp_filter.cwl/hard_filter/reference"
                        },
                        {
                            "source": "#fp_filter.cwl/fp_index/indexed_vcf",
                            "id": "#fp_filter.cwl/hard_filter/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/hard_filter/filtered_vcf"
                    ],
                    "id": "#fp_filter.cwl/hard_filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/decompose_variants/decomposed_vcf",
                            "id": "#fp_filter.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/index/indexed_vcf"
                    ],
                    "id": "#fp_filter.cwl/index"
                },
                {
                    "run": "#normalize_variants.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/reference",
                            "id": "#fp_filter.cwl/normalize_variants/reference"
                        },
                        {
                            "source": "#fp_filter.cwl/sanitize_vcf/sanitized_vcf",
                            "id": "#fp_filter.cwl/normalize_variants/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/normalize_variants/normalized_vcf"
                    ],
                    "id": "#fp_filter.cwl/normalize_variants"
                },
                {
                    "run": "#vcf_sanitize.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/vcf",
                            "id": "#fp_filter.cwl/sanitize_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/sanitize_vcf/sanitized_vcf"
                    ],
                    "id": "#fp_filter.cwl/sanitize_vcf"
                }
            ],
            "id": "#fp_filter.cwl"
        },
        {
            "class": "Workflow",
            "label": "mutect parallel workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#mutect.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#mutect.cwl/normal_bam"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#mutect.cwl/reference"
                },
                {
                    "type": "int",
                    "id": "#mutect.cwl/scatter_count"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai",
                        ".bai"
                    ],
                    "id": "#mutect.cwl/tumor_bam"
                },
                {
                    "type": "string",
                    "id": "#mutect.cwl/tumor_sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#mutect.cwl/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#mutect.cwl/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#fp_filter.cwl",
                    "in": [
                        {
                            "source": "#mutect.cwl/tumor_bam",
                            "id": "#mutect.cwl/filter/bam"
                        },
                        {
                            "source": "#mutect.cwl/reference",
                            "id": "#mutect.cwl/filter/reference"
                        },
                        {
                            "source": "#mutect.cwl/tumor_sample_name",
                            "id": "#mutect.cwl/filter/sample_name"
                        },
                        {
                            "valueFrom": "mutect",
                            "id": "#mutect.cwl/filter/variant_caller"
                        },
                        {
                            "source": "#mutect.cwl/index/indexed_vcf",
                            "id": "#mutect.cwl/filter/vcf"
                        }
                    ],
                    "out": [
                        "#mutect.cwl/filter/unfiltered_vcf",
                        "#mutect.cwl/filter/filtered_vcf"
                    ],
                    "id": "#mutect.cwl/filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#mutect.cwl/merge/merged_vcf",
                            "id": "#mutect.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#mutect.cwl/index/indexed_vcf"
                    ],
                    "id": "#mutect.cwl/index"
                },
                {
                    "run": "#merge_vcf.cwl",
                    "in": [
                        {
                            "source": "#mutect.cwl/mutect/vcf",
                            "id": "#mutect.cwl/merge/vcfs"
                        }
                    ],
                    "out": [
                        "#mutect.cwl/merge/merged_vcf"
                    ],
                    "id": "#mutect.cwl/merge"
                },
                {
                    "scatter": "#mutect.cwl/mutect/interval_list",
                    "run": "#mutect.cwl_2",
                    "in": [
                        {
                            "source": "#mutect.cwl/split_interval_list/split_interval_lists",
                            "id": "#mutect.cwl/mutect/interval_list"
                        },
                        {
                            "source": "#mutect.cwl/normal_bam",
                            "id": "#mutect.cwl/mutect/normal_bam"
                        },
                        {
                            "source": "#mutect.cwl/reference",
                            "id": "#mutect.cwl/mutect/reference"
                        },
                        {
                            "source": "#mutect.cwl/tumor_bam",
                            "id": "#mutect.cwl/mutect/tumor_bam"
                        }
                    ],
                    "out": [
                        "#mutect.cwl/mutect/vcf"
                    ],
                    "id": "#mutect.cwl/mutect"
                },
                {
                    "run": "#split_interval_list.cwl",
                    "in": [
                        {
                            "source": "#mutect.cwl/interval_list",
                            "id": "#mutect.cwl/split_interval_list/interval_list"
                        },
                        {
                            "source": "#mutect.cwl/scatter_count",
                            "id": "#mutect.cwl/split_interval_list/scatter_count"
                        }
                    ],
                    "out": [
                        "#mutect.cwl/split_interval_list/split_interval_lists"
                    ],
                    "id": "#mutect.cwl/split_interval_list"
                }
            ],
            "id": "#mutect.cwl"
        },
        {
            "class": "Workflow",
            "label": "pindel parallel workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "default": 400,
                    "id": "#pindel.cwl/insert_size"
                },
                {
                    "type": "File",
                    "id": "#pindel.cwl/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#pindel.cwl/normal_bam"
                },
                {
                    "type": "string",
                    "id": "#pindel.cwl/normal_sample_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#pindel.cwl/reference"
                },
                {
                    "type": "int",
                    "default": 50,
                    "id": "#pindel.cwl/scatter_count"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#pindel.cwl/tumor_bam"
                },
                {
                    "type": "string",
                    "id": "#pindel.cwl/tumor_sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#pindel.cwl/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#pindel.cwl/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#pindel.cwl/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#pindel.cwl/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#pindel.cwl/somaticfilter/vcf",
                            "id": "#pindel.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#pindel.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#pindel.cwl/bgzip"
                },
                {
                    "run": "#cat_all.cwl",
                    "in": [
                        {
                            "source": "#pindel.cwl/pindel_cat/per_region_pindel_out",
                            "id": "#pindel.cwl/cat_all/region_pindel_outs"
                        }
                    ],
                    "out": [
                        "#pindel.cwl/cat_all/all_region_pindel_head"
                    ],
                    "id": "#pindel.cwl/cat_all"
                },
                {
                    "run": "#fp_filter.cwl",
                    "in": [
                        {
                            "source": "#pindel.cwl/tumor_bam",
                            "id": "#pindel.cwl/filter/bam"
                        },
                        {
                            "source": "#pindel.cwl/reference",
                            "id": "#pindel.cwl/filter/reference"
                        },
                        {
                            "source": "#pindel.cwl/tumor_sample_name",
                            "id": "#pindel.cwl/filter/sample_name"
                        },
                        {
                            "valueFrom": "pindel",
                            "id": "#pindel.cwl/filter/variant_caller"
                        },
                        {
                            "source": "#pindel.cwl/reindex/indexed_vcf",
                            "id": "#pindel.cwl/filter/vcf"
                        }
                    ],
                    "out": [
                        "#pindel.cwl/filter/unfiltered_vcf",
                        "#pindel.cwl/filter/filtered_vcf"
                    ],
                    "id": "#pindel.cwl/filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#pindel.cwl/bgzip/bgzipped_file",
                            "id": "#pindel.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#pindel.cwl/index/indexed_vcf"
                    ],
                    "id": "#pindel.cwl/index"
                },
                {
                    "scatter": "#pindel.cwl/pindel_cat/region_file",
                    "run": "#pindel_cat.cwl",
                    "in": [
                        {
                            "source": "#pindel.cwl/insert_size",
                            "id": "#pindel.cwl/pindel_cat/insert_size"
                        },
                        {
                            "source": "#pindel.cwl/normal_bam",
                            "id": "#pindel.cwl/pindel_cat/normal_bam"
                        },
                        {
                            "source": "#pindel.cwl/normal_sample_name",
                            "id": "#pindel.cwl/pindel_cat/normal_sample_name"
                        },
                        {
                            "source": "#pindel.cwl/reference",
                            "id": "#pindel.cwl/pindel_cat/reference"
                        },
                        {
                            "source": "#pindel.cwl/split_interval_list_to_bed/split_beds",
                            "id": "#pindel.cwl/pindel_cat/region_file"
                        },
                        {
                            "source": "#pindel.cwl/tumor_bam",
                            "id": "#pindel.cwl/pindel_cat/tumor_bam"
                        },
                        {
                            "source": "#pindel.cwl/tumor_sample_name",
                            "id": "#pindel.cwl/pindel_cat/tumor_sample_name"
                        }
                    ],
                    "out": [
                        "#pindel.cwl/pindel_cat/per_region_pindel_out"
                    ],
                    "id": "#pindel.cwl/pindel_cat"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#pindel.cwl/remove_end_tags/processed_vcf",
                            "id": "#pindel.cwl/reindex/vcf"
                        }
                    ],
                    "out": [
                        "#pindel.cwl/reindex/indexed_vcf"
                    ],
                    "id": "#pindel.cwl/reindex"
                },
                {
                    "run": "#remove_end_tags.cwl",
                    "in": [
                        {
                            "source": "#pindel.cwl/index/indexed_vcf",
                            "id": "#pindel.cwl/remove_end_tags/vcf"
                        }
                    ],
                    "out": [
                        "#pindel.cwl/remove_end_tags/processed_vcf"
                    ],
                    "id": "#pindel.cwl/remove_end_tags"
                },
                {
                    "run": "#pindel_somatic_filter.cwl",
                    "in": [
                        {
                            "source": "#pindel.cwl/cat_all/all_region_pindel_head",
                            "id": "#pindel.cwl/somaticfilter/pindel_output_summary"
                        },
                        {
                            "source": "#pindel.cwl/reference",
                            "id": "#pindel.cwl/somaticfilter/reference"
                        }
                    ],
                    "out": [
                        "#pindel.cwl/somaticfilter/vcf"
                    ],
                    "id": "#pindel.cwl/somaticfilter"
                },
                {
                    "run": "#split_interval_list_to_bed.cwl",
                    "in": [
                        {
                            "source": "#pindel.cwl/interval_list",
                            "id": "#pindel.cwl/split_interval_list_to_bed/interval_list"
                        },
                        {
                            "source": "#pindel.cwl/scatter_count",
                            "id": "#pindel.cwl/split_interval_list_to_bed/scatter_count"
                        }
                    ],
                    "out": [
                        "#pindel.cwl/split_interval_list_to_bed/split_beds"
                    ],
                    "id": "#pindel.cwl/split_interval_list_to_bed"
                }
            ],
            "id": "#pindel.cwl"
        },
        {
            "class": "Workflow",
            "label": "Per-region pindel",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "default": 400,
                    "id": "#pindel_cat.cwl/insert_size"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#pindel_cat.cwl/normal_bam"
                },
                {
                    "type": "string",
                    "id": "#pindel_cat.cwl/normal_sample_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#pindel_cat.cwl/reference"
                },
                {
                    "type": "File",
                    "id": "#pindel_cat.cwl/region_file"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#pindel_cat.cwl/tumor_bam"
                },
                {
                    "type": "string",
                    "id": "#pindel_cat.cwl/tumor_sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#pindel_cat.cwl/cat/pindel_out",
                    "id": "#pindel_cat.cwl/per_region_pindel_out"
                }
            ],
            "steps": [
                {
                    "run": "#cat_out.cwl",
                    "in": [
                        {
                            "source": [
                                "#pindel_cat.cwl/pindel/deletions",
                                "#pindel_cat.cwl/pindel/insertions",
                                "#pindel_cat.cwl/pindel/tandems",
                                "#pindel_cat.cwl/pindel/long_insertions",
                                "#pindel_cat.cwl/pindel/inversions"
                            ],
                            "id": "#pindel_cat.cwl/cat/pindel_outs"
                        }
                    ],
                    "out": [
                        "#pindel_cat.cwl/cat/pindel_out"
                    ],
                    "id": "#pindel_cat.cwl/cat"
                },
                {
                    "run": "#pindel.cwl_2",
                    "in": [
                        {
                            "source": "#pindel_cat.cwl/insert_size",
                            "id": "#pindel_cat.cwl/pindel/insert_size"
                        },
                        {
                            "source": "#pindel_cat.cwl/normal_bam",
                            "id": "#pindel_cat.cwl/pindel/normal_bam"
                        },
                        {
                            "source": "#pindel_cat.cwl/normal_sample_name",
                            "id": "#pindel_cat.cwl/pindel/normal_sample_name"
                        },
                        {
                            "source": "#pindel_cat.cwl/reference",
                            "id": "#pindel_cat.cwl/pindel/reference"
                        },
                        {
                            "source": "#pindel_cat.cwl/region_file",
                            "id": "#pindel_cat.cwl/pindel/region_file"
                        },
                        {
                            "source": "#pindel_cat.cwl/tumor_bam",
                            "id": "#pindel_cat.cwl/pindel/tumor_bam"
                        },
                        {
                            "source": "#pindel_cat.cwl/tumor_sample_name",
                            "id": "#pindel_cat.cwl/pindel/tumor_sample_name"
                        }
                    ],
                    "out": [
                        "#pindel_cat.cwl/pindel/deletions",
                        "#pindel_cat.cwl/pindel/insertions",
                        "#pindel_cat.cwl/pindel/tandems",
                        "#pindel_cat.cwl/pindel/long_insertions",
                        "#pindel_cat.cwl/pindel/inversions"
                    ],
                    "id": "#pindel_cat.cwl/pindel"
                }
            ],
            "id": "#pindel_cat.cwl"
        },
        {
            "class": "Workflow",
            "label": "strelka workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#strelka_and_post_processing.cwl/cpu_reserved"
                },
                {
                    "type": "boolean",
                    "id": "#strelka_and_post_processing.cwl/exome_mode"
                },
                {
                    "type": "File",
                    "id": "#strelka_and_post_processing.cwl/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#strelka_and_post_processing.cwl/normal_bam"
                },
                {
                    "type": "string",
                    "id": "#strelka_and_post_processing.cwl/normal_sample_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#strelka_and_post_processing.cwl/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#strelka_and_post_processing.cwl/tumor_bam"
                },
                {
                    "type": "string",
                    "id": "#strelka_and_post_processing.cwl/tumor_sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#strelka_and_post_processing.cwl/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#strelka_and_post_processing.cwl/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#strelka_and_post_processing.cwl/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#strelka_and_post_processing.cwl/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#fp_filter.cwl",
                    "in": [
                        {
                            "source": "#strelka_and_post_processing.cwl/tumor_bam",
                            "id": "#strelka_and_post_processing.cwl/filter/bam"
                        },
                        {
                            "source": "#strelka_and_post_processing.cwl/reference",
                            "id": "#strelka_and_post_processing.cwl/filter/reference"
                        },
                        {
                            "source": "#strelka_and_post_processing.cwl/tumor_sample_name",
                            "id": "#strelka_and_post_processing.cwl/filter/sample_name"
                        },
                        {
                            "valueFrom": "strelka",
                            "id": "#strelka_and_post_processing.cwl/filter/variant_caller"
                        },
                        {
                            "source": "#strelka_and_post_processing.cwl/region_filter/filtered_vcf",
                            "id": "#strelka_and_post_processing.cwl/filter/vcf"
                        }
                    ],
                    "out": [
                        "#strelka_and_post_processing.cwl/filter/unfiltered_vcf",
                        "#strelka_and_post_processing.cwl/filter/filtered_vcf"
                    ],
                    "id": "#strelka_and_post_processing.cwl/filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#strelka_and_post_processing.cwl/rename_normal_sample/renamed_vcf",
                            "id": "#strelka_and_post_processing.cwl/index_full/vcf"
                        }
                    ],
                    "out": [
                        "#strelka_and_post_processing.cwl/index_full/indexed_vcf"
                    ],
                    "id": "#strelka_and_post_processing.cwl/index_full"
                },
                {
                    "run": "#merge_vcf.cwl",
                    "in": [
                        {
                            "source": "#strelka_and_post_processing.cwl/process/processed_vcf",
                            "id": "#strelka_and_post_processing.cwl/merge/vcfs"
                        }
                    ],
                    "out": [
                        "#strelka_and_post_processing.cwl/merge/merged_vcf"
                    ],
                    "id": "#strelka_and_post_processing.cwl/merge"
                },
                {
                    "scatter": "#strelka_and_post_processing.cwl/process/vcf",
                    "run": "#strelka_process_vcf.cwl",
                    "in": [
                        {
                            "source": [
                                "#strelka_and_post_processing.cwl/strelka/snvs",
                                "#strelka_and_post_processing.cwl/strelka/indels"
                            ],
                            "id": "#strelka_and_post_processing.cwl/process/vcf"
                        }
                    ],
                    "out": [
                        "#strelka_and_post_processing.cwl/process/processed_vcf"
                    ],
                    "id": "#strelka_and_post_processing.cwl/process"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "source": "#strelka_and_post_processing.cwl/interval_list",
                            "id": "#strelka_and_post_processing.cwl/region_filter/interval_list"
                        },
                        {
                            "source": "#strelka_and_post_processing.cwl/reference",
                            "id": "#strelka_and_post_processing.cwl/region_filter/reference"
                        },
                        {
                            "source": "#strelka_and_post_processing.cwl/index_full/indexed_vcf",
                            "id": "#strelka_and_post_processing.cwl/region_filter/vcf"
                        }
                    ],
                    "out": [
                        "#strelka_and_post_processing.cwl/region_filter/filtered_vcf"
                    ],
                    "id": "#strelka_and_post_processing.cwl/region_filter"
                },
                {
                    "run": "#replace_vcf_sample_name.cwl",
                    "in": [
                        {
                            "source": "#strelka_and_post_processing.cwl/rename_tumor_sample/renamed_vcf",
                            "id": "#strelka_and_post_processing.cwl/rename_normal_sample/input_vcf"
                        },
                        {
                            "source": "#strelka_and_post_processing.cwl/normal_sample_name",
                            "id": "#strelka_and_post_processing.cwl/rename_normal_sample/new_sample_name"
                        },
                        {
                            "default": "NORMAL",
                            "id": "#strelka_and_post_processing.cwl/rename_normal_sample/sample_to_replace"
                        }
                    ],
                    "out": [
                        "#strelka_and_post_processing.cwl/rename_normal_sample/renamed_vcf"
                    ],
                    "id": "#strelka_and_post_processing.cwl/rename_normal_sample"
                },
                {
                    "run": "#replace_vcf_sample_name.cwl",
                    "in": [
                        {
                            "source": "#strelka_and_post_processing.cwl/merge/merged_vcf",
                            "id": "#strelka_and_post_processing.cwl/rename_tumor_sample/input_vcf"
                        },
                        {
                            "source": "#strelka_and_post_processing.cwl/tumor_sample_name",
                            "id": "#strelka_and_post_processing.cwl/rename_tumor_sample/new_sample_name"
                        },
                        {
                            "default": "TUMOR",
                            "id": "#strelka_and_post_processing.cwl/rename_tumor_sample/sample_to_replace"
                        }
                    ],
                    "out": [
                        "#strelka_and_post_processing.cwl/rename_tumor_sample/renamed_vcf"
                    ],
                    "id": "#strelka_and_post_processing.cwl/rename_tumor_sample"
                },
                {
                    "run": "#strelka.cwl",
                    "in": [
                        {
                            "source": "#strelka_and_post_processing.cwl/cpu_reserved",
                            "id": "#strelka_and_post_processing.cwl/strelka/cpu_reserved"
                        },
                        {
                            "source": "#strelka_and_post_processing.cwl/exome_mode",
                            "id": "#strelka_and_post_processing.cwl/strelka/exome_mode"
                        },
                        {
                            "source": "#strelka_and_post_processing.cwl/normal_bam",
                            "id": "#strelka_and_post_processing.cwl/strelka/normal_bam"
                        },
                        {
                            "source": "#strelka_and_post_processing.cwl/reference",
                            "id": "#strelka_and_post_processing.cwl/strelka/reference"
                        },
                        {
                            "source": "#strelka_and_post_processing.cwl/tumor_bam",
                            "id": "#strelka_and_post_processing.cwl/strelka/tumor_bam"
                        }
                    ],
                    "out": [
                        "#strelka_and_post_processing.cwl/strelka/indels",
                        "#strelka_and_post_processing.cwl/strelka/snvs"
                    ],
                    "id": "#strelka_and_post_processing.cwl/strelka"
                }
            ],
            "id": "#strelka_and_post_processing.cwl"
        },
        {
            "class": "Workflow",
            "label": "process VCF workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#strelka_process_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#strelka_process_vcf.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#strelka_process_vcf.cwl/processed_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#add_strelka_gt.cwl",
                    "in": [
                        {
                            "source": "#strelka_process_vcf.cwl/vcf",
                            "id": "#strelka_process_vcf.cwl/add_gt/vcf"
                        }
                    ],
                    "out": [
                        "#strelka_process_vcf.cwl/add_gt/processed_vcf"
                    ],
                    "id": "#strelka_process_vcf.cwl/add_gt"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#strelka_process_vcf.cwl/add_gt/processed_vcf",
                            "id": "#strelka_process_vcf.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#strelka_process_vcf.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#strelka_process_vcf.cwl/bgzip"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#strelka_process_vcf.cwl/bgzip/bgzipped_file",
                            "id": "#strelka_process_vcf.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#strelka_process_vcf.cwl/index/indexed_vcf"
                    ],
                    "id": "#strelka_process_vcf.cwl/index"
                }
            ],
            "id": "#strelka_process_vcf.cwl"
        },
        {
            "class": "Workflow",
            "label": "varscan somatic workflow",
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#varscan.cwl/max_normal_freq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#varscan.cwl/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#varscan.cwl/min_var_freq"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#varscan.cwl/normal_bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#varscan.cwl/p_value"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#varscan.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#varscan.cwl/roi_bed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#varscan.cwl/strand_filter"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#varscan.cwl/tumor_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/germline_hc",
                    "id": "#varscan.cwl/germline_hc_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/germline_hc",
                    "id": "#varscan.cwl/germline_hc_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/germline",
                    "id": "#varscan.cwl/germline_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/germline",
                    "id": "#varscan.cwl/germline_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/somatic/indels",
                    "id": "#varscan.cwl/indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/loh_hc",
                    "id": "#varscan.cwl/loh_hc_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/loh_hc",
                    "id": "#varscan.cwl/loh_hc_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/loh",
                    "id": "#varscan.cwl/loh_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/loh",
                    "id": "#varscan.cwl/loh_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/somatic/snvs",
                    "id": "#varscan.cwl/snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/somatic_hc",
                    "id": "#varscan.cwl/somatic_hc_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/somatic_hc",
                    "id": "#varscan.cwl/somatic_hc_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/somatic",
                    "id": "#varscan.cwl/somatic_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/somatic",
                    "id": "#varscan.cwl/somatic_snvs"
                }
            ],
            "steps": [
                {
                    "run": "#varscan_process_somatic.cwl",
                    "in": [
                        {
                            "source": "#varscan.cwl/max_normal_freq",
                            "id": "#varscan.cwl/process_somatic_indels/max_normal_freq"
                        },
                        {
                            "source": "#varscan.cwl/somatic/indels",
                            "id": "#varscan.cwl/process_somatic_indels/variants"
                        }
                    ],
                    "out": [
                        "#varscan.cwl/process_somatic_indels/somatic_hc",
                        "#varscan.cwl/process_somatic_indels/somatic",
                        "#varscan.cwl/process_somatic_indels/germline_hc",
                        "#varscan.cwl/process_somatic_indels/germline",
                        "#varscan.cwl/process_somatic_indels/loh_hc",
                        "#varscan.cwl/process_somatic_indels/loh"
                    ],
                    "id": "#varscan.cwl/process_somatic_indels"
                },
                {
                    "run": "#varscan_process_somatic.cwl",
                    "in": [
                        {
                            "source": "#varscan.cwl/max_normal_freq",
                            "id": "#varscan.cwl/process_somatic_snvs/max_normal_freq"
                        },
                        {
                            "source": "#varscan.cwl/somatic/snvs",
                            "id": "#varscan.cwl/process_somatic_snvs/variants"
                        }
                    ],
                    "out": [
                        "#varscan.cwl/process_somatic_snvs/somatic_hc",
                        "#varscan.cwl/process_somatic_snvs/somatic",
                        "#varscan.cwl/process_somatic_snvs/germline_hc",
                        "#varscan.cwl/process_somatic_snvs/germline",
                        "#varscan.cwl/process_somatic_snvs/loh_hc",
                        "#varscan.cwl/process_somatic_snvs/loh"
                    ],
                    "id": "#varscan.cwl/process_somatic_snvs"
                },
                {
                    "run": "#varscan_somatic.cwl",
                    "in": [
                        {
                            "source": "#varscan.cwl/min_coverage",
                            "id": "#varscan.cwl/somatic/min_coverage"
                        },
                        {
                            "source": "#varscan.cwl/min_var_freq",
                            "id": "#varscan.cwl/somatic/min_var_freq"
                        },
                        {
                            "source": "#varscan.cwl/normal_bam",
                            "id": "#varscan.cwl/somatic/normal_bam"
                        },
                        {
                            "source": "#varscan.cwl/p_value",
                            "id": "#varscan.cwl/somatic/p_value"
                        },
                        {
                            "source": "#varscan.cwl/reference",
                            "id": "#varscan.cwl/somatic/reference"
                        },
                        {
                            "source": "#varscan.cwl/roi_bed",
                            "id": "#varscan.cwl/somatic/roi_bed"
                        },
                        {
                            "source": "#varscan.cwl/strand_filter",
                            "id": "#varscan.cwl/somatic/strand_filter"
                        },
                        {
                            "source": "#varscan.cwl/tumor_bam",
                            "id": "#varscan.cwl/somatic/tumor_bam"
                        }
                    ],
                    "out": [
                        "#varscan.cwl/somatic/snvs",
                        "#varscan.cwl/somatic/indels"
                    ],
                    "id": "#varscan.cwl/somatic"
                }
            ],
            "id": "#varscan.cwl"
        },
        {
            "class": "Workflow",
            "label": "Varscan Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#varscan_pre_and_post_processing.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/max_normal_freq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#varscan_pre_and_post_processing.cwl/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "id": "#varscan_pre_and_post_processing.cwl/min_var_freq"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/normal_bam"
                },
                {
                    "type": "string",
                    "id": "#varscan_pre_and_post_processing.cwl/normal_sample_name"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "id": "#varscan_pre_and_post_processing.cwl/p_value"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#varscan_pre_and_post_processing.cwl/strand_filter"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai",
                        ".bai"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/tumor_bam"
                },
                {
                    "type": "string",
                    "id": "#varscan_pre_and_post_processing.cwl/tumor_sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#varscan_pre_and_post_processing.cwl/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan_pre_and_post_processing.cwl/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/varscan/somatic_hc_indels",
                            "id": "#varscan_pre_and_post_processing.cwl/bgzip_and_index_hc_indels/vcf"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/bgzip_and_index_hc_indels/indexed_vcf"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/bgzip_and_index_hc_indels"
                },
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/varscan/somatic_hc_snvs",
                            "id": "#varscan_pre_and_post_processing.cwl/bgzip_and_index_hc_snvs/vcf"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/bgzip_and_index_hc_snvs/indexed_vcf"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/bgzip_and_index_hc_snvs"
                },
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/varscan/somatic_indels",
                            "id": "#varscan_pre_and_post_processing.cwl/bgzip_and_index_indels/vcf"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/bgzip_and_index_indels/indexed_vcf"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/bgzip_and_index_indels"
                },
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/varscan/somatic_snvs",
                            "id": "#varscan_pre_and_post_processing.cwl/bgzip_and_index_snvs/vcf"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/bgzip_and_index_snvs/indexed_vcf"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/bgzip_and_index_snvs"
                },
                {
                    "run": "#fp_filter.cwl",
                    "in": [
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/tumor_bam",
                            "id": "#varscan_pre_and_post_processing.cwl/filter/bam"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/min_var_freq",
                            "id": "#varscan_pre_and_post_processing.cwl/filter/min_var_freq"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/reference",
                            "id": "#varscan_pre_and_post_processing.cwl/filter/reference"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/tumor_sample_name",
                            "id": "#varscan_pre_and_post_processing.cwl/filter/sample_name"
                        },
                        {
                            "valueFrom": "varscan",
                            "id": "#varscan_pre_and_post_processing.cwl/filter/variant_caller"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/index/indexed_vcf",
                            "id": "#varscan_pre_and_post_processing.cwl/filter/vcf"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/filter/unfiltered_vcf",
                        "#varscan_pre_and_post_processing.cwl/filter/filtered_vcf"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/rename_normal_sample/renamed_vcf",
                            "id": "#varscan_pre_and_post_processing.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/index/indexed_vcf"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/index"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/merge_indels/merged_vcf",
                            "id": "#varscan_pre_and_post_processing.cwl/index_indels/vcf"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/index_indels/indexed_vcf"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/index_indels"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/merge_snvs/merged_vcf",
                            "id": "#varscan_pre_and_post_processing.cwl/index_snvs/vcf"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/index_snvs/indexed_vcf"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/index_snvs"
                },
                {
                    "run": "#intervals_to_bed.cwl",
                    "in": [
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/interval_list",
                            "id": "#varscan_pre_and_post_processing.cwl/intervals_to_bed/interval_list"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/intervals_to_bed/interval_bed"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/intervals_to_bed"
                },
                {
                    "run": "#merge_vcf.cwl",
                    "in": [
                        {
                            "source": [
                                "#varscan_pre_and_post_processing.cwl/index_snvs/indexed_vcf",
                                "#varscan_pre_and_post_processing.cwl/index_indels/indexed_vcf"
                            ],
                            "id": "#varscan_pre_and_post_processing.cwl/merge/vcfs"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/merge/merged_vcf"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/merge"
                },
                {
                    "run": "#set_filter_status.cwl",
                    "in": [
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/bgzip_and_index_hc_indels/indexed_vcf",
                            "id": "#varscan_pre_and_post_processing.cwl/merge_indels/filtered_vcf"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/reference",
                            "id": "#varscan_pre_and_post_processing.cwl/merge_indels/reference"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/bgzip_and_index_indels/indexed_vcf",
                            "id": "#varscan_pre_and_post_processing.cwl/merge_indels/vcf"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/merge_indels/merged_vcf"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/merge_indels"
                },
                {
                    "run": "#set_filter_status.cwl",
                    "in": [
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/bgzip_and_index_hc_snvs/indexed_vcf",
                            "id": "#varscan_pre_and_post_processing.cwl/merge_snvs/filtered_vcf"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/reference",
                            "id": "#varscan_pre_and_post_processing.cwl/merge_snvs/reference"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/bgzip_and_index_snvs/indexed_vcf",
                            "id": "#varscan_pre_and_post_processing.cwl/merge_snvs/vcf"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/merge_snvs/merged_vcf"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/merge_snvs"
                },
                {
                    "run": "#replace_vcf_sample_name.cwl",
                    "in": [
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/rename_tumor_sample/renamed_vcf",
                            "id": "#varscan_pre_and_post_processing.cwl/rename_normal_sample/input_vcf"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/normal_sample_name",
                            "id": "#varscan_pre_and_post_processing.cwl/rename_normal_sample/new_sample_name"
                        },
                        {
                            "default": "NORMAL",
                            "id": "#varscan_pre_and_post_processing.cwl/rename_normal_sample/sample_to_replace"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/rename_normal_sample/renamed_vcf"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/rename_normal_sample"
                },
                {
                    "run": "#replace_vcf_sample_name.cwl",
                    "in": [
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/merge/merged_vcf",
                            "id": "#varscan_pre_and_post_processing.cwl/rename_tumor_sample/input_vcf"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/tumor_sample_name",
                            "id": "#varscan_pre_and_post_processing.cwl/rename_tumor_sample/new_sample_name"
                        },
                        {
                            "default": "TUMOR",
                            "id": "#varscan_pre_and_post_processing.cwl/rename_tumor_sample/sample_to_replace"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/rename_tumor_sample/renamed_vcf"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/rename_tumor_sample"
                },
                {
                    "run": "#varscan.cwl",
                    "in": [
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/max_normal_freq",
                            "id": "#varscan_pre_and_post_processing.cwl/varscan/max_normal_freq"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/min_coverage",
                            "id": "#varscan_pre_and_post_processing.cwl/varscan/min_coverage"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/min_var_freq",
                            "id": "#varscan_pre_and_post_processing.cwl/varscan/min_var_freq"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/normal_bam",
                            "id": "#varscan_pre_and_post_processing.cwl/varscan/normal_bam"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/p_value",
                            "id": "#varscan_pre_and_post_processing.cwl/varscan/p_value"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/reference",
                            "id": "#varscan_pre_and_post_processing.cwl/varscan/reference"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/intervals_to_bed/interval_bed",
                            "id": "#varscan_pre_and_post_processing.cwl/varscan/roi_bed"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/strand_filter",
                            "id": "#varscan_pre_and_post_processing.cwl/varscan/strand_filter"
                        },
                        {
                            "source": "#varscan_pre_and_post_processing.cwl/tumor_bam",
                            "id": "#varscan_pre_and_post_processing.cwl/varscan/tumor_bam"
                        }
                    ],
                    "out": [
                        "#varscan_pre_and_post_processing.cwl/varscan/somatic_snvs",
                        "#varscan_pre_and_post_processing.cwl/varscan/somatic_indels",
                        "#varscan_pre_and_post_processing.cwl/varscan/somatic_hc_snvs",
                        "#varscan_pre_and_post_processing.cwl/varscan/somatic_hc_indels"
                    ],
                    "id": "#varscan_pre_and_post_processing.cwl/varscan"
                }
            ],
            "id": "#varscan_pre_and_post_processing.cwl"
        },
        {
            "class": "Workflow",
            "label": "Add snv and indel bam-readcount files to a vcf",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        {
                            "type": "enum",
                            "symbols": [
                                "#vcf_readcount_annotator.cwl/data_type/DNA",
                                "#vcf_readcount_annotator.cwl/data_type/RNA"
                            ]
                        }
                    ],
                    "id": "#vcf_readcount_annotator.cwl/data_type"
                },
                {
                    "type": "File",
                    "id": "#vcf_readcount_annotator.cwl/indel_bam_readcount_tsv"
                },
                {
                    "type": "string",
                    "id": "#vcf_readcount_annotator.cwl/sample_name"
                },
                {
                    "type": "File",
                    "id": "#vcf_readcount_annotator.cwl/snv_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#vcf_readcount_annotator.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                    "id": "#vcf_readcount_annotator.cwl/annotated_bam_readcount_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#vcf_readcount_annotator.cwl_2",
                    "in": [
                        {
                            "source": "#vcf_readcount_annotator.cwl/indel_bam_readcount_tsv",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/bam_readcount_tsv"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/data_type",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/sample_name",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "default": "indel",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/variant_type"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf"
                },
                {
                    "run": "#vcf_readcount_annotator.cwl_2",
                    "in": [
                        {
                            "source": "#vcf_readcount_annotator.cwl/snv_bam_readcount_tsv",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/bam_readcount_tsv"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/data_type",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/sample_name",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "default": "snv",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/variant_type"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/vcf",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf"
                }
            ],
            "id": "#vcf_readcount_annotator.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add GT tags",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:bionic"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "add_strelka_gt.pl",
                            "entry": "#!/usr/bin/perl\n\nuse strict;\nuse warnings;\n\nuse feature qw(say);\n\ndie(\"wrong number of arguments\") unless scalar(@ARGV) == 2;\nmy ($strelka_vcf, $outdir) = @ARGV;\n\nopen(my $strelka_vcf_fh, '-|', '/bin/gunzip', '-c', $strelka_vcf) \n    or die(\"couldn't open $strelka_vcf to read\");\nopen(my $add_gt_fh, \">\", \"$outdir/add_gt.vcf\") \n    or die(\"couldn't open add_gt.vcf for write\");\n\nwhile (<$strelka_vcf_fh>) {\n    chomp;\n    if (/^##/) {\n        say $add_gt_fh $_;\n    }\n    elsif (/^#/) { #COLUMN HEADER\n        say $add_gt_fh '##FORMAT=<ID=GT,Number=1,Type=String,Description=\"Genotype\">';\n        say $add_gt_fh $_;\n    }\n    else {\n        my @columns = split /\\t/, $_;\n        my ($ref, $alt, $info) = map{$columns[$_]}(3, 4, 7);\n        my @alts = split /,/, $alt;\n\n        my ($n_gt, $t_gt);\n\n        if (length($ref) == 1 and length($alts[0]) == 1) {\n            my ($n_gt_info, $n_gt_str, $t_gt_str) = $info =~ /NT=(\\S+?);QSS.*SGT=(\\S+?)\\->(\\S+?);/;\n            unshift @alts, $ref;\n\n            my %ids;\n            my $id = 0;\n\n            for my $base (@alts) {\n                $ids{$base} = $id;\n                $id++;\n            }\n\n            $n_gt = $n_gt_info eq 'ref' ? '0/0' : parse_gt($n_gt_str, \\%ids);\n            $t_gt = parse_gt($t_gt_str, \\%ids);\n        }\n        else {#INDEL\n            my ($n_gt_info, $t_gt_info) = $info =~ /;NT=(\\S+?);.*SGT.*\\->(\\S+?);/;\n\n            my %gt_info = (\n                ref => '0/0',\n                het => '0/1',\n                hom => '1/1',\n                conflict => './.',\n            );\n\n            $n_gt = $gt_info{$n_gt_info};\n            $t_gt = $gt_info{$t_gt_info};\n        }\n\n        $columns[8]  = 'GT:'.$columns[8];\n        $columns[9]  = $n_gt . ':' . $columns[9];\n        $columns[10] = $t_gt . ':' . $columns[10];\n\n        my $new_str = join \"\\t\", @columns;\n        say $add_gt_fh $new_str;\n    }\n}\n\nclose($strelka_vcf_fh);\nclose($add_gt_fh);\n\n\nsub parse_gt {\n    my ($gt_str, $ids) = @_;\n    my @gt_ids = map{$ids->{$_}}(split //, $gt_str);\n    return join '/', sort @gt_ids;\n}\n\n#SNV example\n#1       10231   .       C       A       .       QSS_ref NT=ref;QSS=1;QSS_NT=1;SGT=AC->AC;SOMATIC;TQSS=2;TQSS_NT=2       DP:FDP:SDP:SUBDP:AU:CU:GU:TU    32:4:8:0:0,3:28,60:0,0:0,1      84:6:69:0:7,21:71,192:0,0:0,1\n#INDEL example\n##1     965051  .       ATGTGTG A       .       QSI_ref IC=5;IHP=2;NT=ref;QSI=1;QSI_NT=1;RC=8;RU=TG;SGT=het->het;SOMATIC;TQSI=1;TQSI_NT=1       DP:DP2:TAR:TIR:TOR:DP50:FDP50:SUBDP50   8:8:6,6:0,0:2,4:10.3:0.00:0.00  18:18:8,8:5,6:5,8:21:0.25:0.00\n"
                        }
                    ]
                }
            ],
            "arguments": [
                "/usr/bin/perl",
                "add_strelka_gt.pl",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#add_strelka_gt.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "add_gt.vcf"
                    },
                    "id": "#add_strelka_gt.cwl/processed_vcf"
                }
            ],
            "id": "#add_strelka_gt.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add VEP annotation to report",
            "baseCommand": [
                "vep-annotation-reporter"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "griffithlab/vatools:3.1.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.prefix).annotated.tsv"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "variants",
                    "id": "#add_vep_fields_to_table.cwl/prefix"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#add_vep_fields_to_table.cwl/tsv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#add_vep_fields_to_table.cwl/vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "Consequence",
                        "SYMBOL",
                        "Feature",
                        "HGVSc",
                        "HGVSp"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#add_vep_fields_to_table.cwl/vep_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.prefix).annotated.tsv"
                    },
                    "id": "#add_vep_fields_to_table.cwl/annotated_variants_tsv"
                }
            ],
            "id": "#add_vep_fields_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "run bam-readcount",
            "baseCommand": [
                "/usr/bin/python",
                "bam_readcount_helper.py"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bam_readcount_helper-cwl:1.1.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "bam_readcount_helper.py",
                            "entry": "#!/usr/bin/env python\n\nimport sys\nimport os\nfrom cyvcf2 import VCF\nimport tempfile\nimport csv\nfrom subprocess import Popen, PIPE\n\ndef generate_region_list(hash):\n    fh = tempfile.NamedTemporaryFile('w', delete=False)\n    writer = csv.writer(fh, delimiter='\\t')\n    for chr, positions in hash.items():\n        for pos in sorted(positions.keys()):\n            writer.writerow([chr, pos, pos])\n    fh.close()\n    return fh.name\n\ndef filter_sites_in_hash(region_list, bam_file, ref_fasta, prefixed_sample, output_dir, insertion_centric, map_qual, base_qual):\n    bam_readcount_cmd = ['/usr/bin/bam-readcount', '-f', ref_fasta, '-l', region_list, '-w', '0', '-b', str(base_qual), '-q', str(map_qual)]\n    if insertion_centric:\n        bam_readcount_cmd.append('-i')\n        output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_indel.tsv')\n    else:\n        output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_snv.tsv')\n    bam_readcount_cmd.append(bam_file)\n    execution = Popen(bam_readcount_cmd, stdout=PIPE, stderr=PIPE)\n    stdout, stderr = execution.communicate()\n    if execution.returncode == 0:\n        with open(output_file, 'wb') as output_fh:\n            output_fh.write(stdout)\n    else:\n        sys.exit(stderr)\n\n#initializing these with default values\nmin_base_qual = 20\nmin_mapping_qual = 0\n\nif len(sys.argv) == 7:\n    (script_name, vcf_filename, sample, ref_fasta, bam_file, prefix, output_dir)= sys.argv\nelif len(sys.argv) == 8:\n    (script_name, vcf_filename, sample, ref_fasta, bam_file, prefix, output_dir, min_base_qual)= sys.argv\nelif len(sys.argv) == 9: #elif instead of else for explicit safety\n    (script_name, vcf_filename, sample, ref_fasta, bam_file, prefix, output_dir, min_base_qual, min_mapping_qual)= sys.argv\n\nif prefix == 'NOPREFIX':\n    prefixed_sample = sample\nelse:\n    prefixed_sample = '_'.join([prefix, sample])\n\nvcf_file = VCF(vcf_filename)\nsample_index = vcf_file.samples.index(sample)\n\nrc_for_indel = {}\nrc_for_snp   = {}\nfor variant in vcf_file:\n    ref = variant.REF\n    chr = variant.CHROM\n    start = variant.start\n    end = variant.end\n    pos = variant.POS\n    for var in  variant.ALT:\n        if len(ref) > 1 or len(var) > 1:\n            #it's an indel or mnp\n            if len(ref) == len(var) or (len(ref) > 1 and len(var) > 1):\n                sys.stderr.write(\"Complex variant or MNP will be skipped: %s\\t%s\\t%s\\t%s\\n\" % (chr, pos, ref , var))\n                continue\n            elif len(ref) > len(var):\n                #it's a deletion\n                pos += 1\n                unmodified_ref = ref\n                ref = unmodified_ref[1]\n                var = \"-%s\" % unmodified_ref[1:]\n            else:\n                #it's an insertion\n                var = \"+%s\" % var[1:]\n            if chr not in rc_for_indel:\n                rc_for_indel[chr] = {}\n            if pos not in rc_for_indel[chr]:\n                rc_for_indel[chr][pos] = {}\n            if ref not in rc_for_indel[chr][pos]:\n                rc_for_indel[chr][pos][ref] = {}\n            rc_for_indel[chr][pos][ref] = variant\n        else:\n            #it's a SNP\n            if chr not in rc_for_snp:\n                rc_for_snp[chr] = {}\n            if pos not in rc_for_snp[chr]:\n                rc_for_snp[chr][pos] = {}\n            if ref not in rc_for_snp[chr][pos]:\n                rc_for_snp[chr][pos][ref] = {}\n            rc_for_snp[chr][pos][ref] = variant\n\nif len(rc_for_snp.keys()) > 0:\n    region_file = generate_region_list(rc_for_snp)\n    filter_sites_in_hash(region_file, bam_file, ref_fasta, prefixed_sample, output_dir, False, min_mapping_qual, min_base_qual)\nelse:\n    output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_snv.tsv')\n    open(output_file, 'w').close()\n\nif len(rc_for_indel.keys()) > 0:\n    region_file = generate_region_list(rc_for_indel)\n    filter_sites_in_hash(region_file, bam_file, ref_fasta, prefixed_sample, output_dir, True, min_mapping_qual, min_base_qual)\nelse:\n    output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_indel.tsv')\n    open(output_file, 'w').close()\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": -3
                }
            ],
            "stdout": "$(inputs.sample)_bam_readcount.tsv",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -5
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bam_readcount.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20,
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#bam_readcount.cwl/min_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#bam_readcount.cwl/min_mapping_quality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "NOPREFIX",
                    "inputBinding": {
                        "position": -4
                    },
                    "id": "#bam_readcount.cwl/prefix"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": -6
                    },
                    "id": "#bam_readcount.cwl/reference_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -7
                    },
                    "id": "#bam_readcount.cwl/sample"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -8
                    },
                    "id": "#bam_readcount.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    var name = \"_bam_readcount_indel.tsv\";\n    if (inputs.prefix.equals(\"NOPREFIX\")) {\n        name = inputs.sample + name;\n    }\n    else {\n        name = inputs.prefix + \"_\" + inputs.sample + name;\n    }\n    return name;\n}\n"
                    },
                    "id": "#bam_readcount.cwl/indel_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    var name = \"_bam_readcount_snv.tsv\";\n    if (inputs.prefix.equals(\"NOPREFIX\")) {\n        name = inputs.sample + name;\n    }\n    else {\n        name = inputs.prefix + \"_\" + inputs.sample + name;\n    }\n    return name;\n}\n"
                    },
                    "id": "#bam_readcount.cwl/snv_bam_readcount_tsv"
                }
            ],
            "id": "#bam_readcount.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/cat"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:xenial"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                {
                    "shellQuote": false,
                    "valueFrom": "|"
                },
                "/bin/grep",
                "ChrID",
                "/dev/stdin"
            ],
            "stdout": "all_region_pindel.head",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#cat_all.cwl/region_pindel_outs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cat_all.cwl/all_region_pindel_head",
                    "outputBinding": {
                        "glob": "all_region_pindel.head"
                    }
                }
            ],
            "id": "#cat_all.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/cat"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:xenial"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "per_chromosome_pindel.out",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cat_out.cwl/pindel_outs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cat_out.cwl/pindel_out",
                    "outputBinding": {
                        "glob": "per_chromosome_pindel.out"
                    }
                }
            ],
            "id": "#cat_out.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "CombineVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "CombineVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 9000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-genotypeMergeOptions",
                "PRIORITIZE",
                "--rod_priority_list",
                "mutect,varscan,strelka,pindel",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/combined.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:mutect",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/mutect_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:pindel",
                        "position": 5
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/pindel_vcf"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#combine_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:strelka",
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/strelka_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:varscan",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/varscan_vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "combined.vcf.gz"
                    },
                    "id": "#combine_variants.cwl/combined_vcf"
                }
            ],
            "id": "#combine_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "CombineVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "CombineVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 9000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-genotypeMergeOptions",
                "PRIORITIZE",
                "--rod_priority_list",
                "callers,docm",
                "--setKey",
                "null",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/merged.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:callers",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#docm_add_variants.cwl/callers_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:docm",
                        "position": 3
                    },
                    "id": "#docm_add_variants.cwl/docm_vcf"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#docm_add_variants.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "merged.vcf.gz"
                    },
                    "id": "#docm_add_variants.cwl/merged_vcf"
                }
            ],
            "id": "#docm_add_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "HaplotypeCaller (GATK4)",
            "baseCommand": [
                "/bin/bash",
                "docm_haplotypeCaller.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 9000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.2.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "docm_haplotypeCaller.sh",
                            "entry": "set -o pipefail\nset -o errexit\n\n# Running haplotype caller using the newly created interval list\nif [[ \"$#\" == 5 ]];then # If normal_bam is passed.\n    # explicitly capturing variables\n    reference=$1\n    normal_bam=$2\n    tumor_bam=$3\n    docm_vcf=$4\n    interval_list=$5\n    # Chaning the interval_list to a new docm_interval_list that spans the docm regions by 200bp\n    cat $interval_list | grep '^@' > docm.interval_list # Extracting the header from the interval_list\n    zcat $docm_vcf | grep ^chr | awk '{FS = \"\\t\";OFS = \"\\t\";print $1,$2-100,$2+100,\"+\",$1\"_\"$2-100\"_\"$2+100}' >> docm.interval_list # Extracting the docm regions with a 100bp flanking region on both directions\n    /gatk/gatk HaplotypeCaller --java-options \"-Xmx8g\" -R $reference -I $normal_bam -I $tumor_bam --alleles $docm_vcf -L docm.interval_list --genotyping-mode GENOTYPE_GIVEN_ALLELES -O docm_raw_variants.vcf\nelse # If normal_bam is not passed\n    reference=$1\n    tumor_bam=$2\n    docm_vcf=$3\n    interval_list=$4\n    # Chaning the interval_list to a new docm_interval_list that spans the docm regions by 200bp\n    cat $interval_list | grep '^@' > docm.interval_list # Extracting the header from the interval_list\n    zcat $docm_vcf | grep ^chr | awk '{FS = \"\\t\";OFS = \"\\t\";print $1,$2-100,$2+100,\"+\",$1\"_\"$2-100\"_\"$2+100}' >> docm.interval_list # Extracting the docm regions with a 100bp flanking region on both directions\n    /gatk/gatk HaplotypeCaller --java-options \"-Xmx8g\" -R $reference -I $tumor_bam --alleles $docm_vcf -L docm.interval_list --genotyping-mode GENOTYPE_GIVEN_ALLELES -O docm_raw_variants.vcf\nfi\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#docm_gatk_haplotype_caller.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#docm_gatk_haplotype_caller.cwl/docm_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#docm_gatk_haplotype_caller.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#docm_gatk_haplotype_caller.cwl/normal_bam"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#docm_gatk_haplotype_caller.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "docm_raw_variants.vcf"
                    },
                    "id": "#docm_gatk_haplotype_caller.cwl/docm_raw_variants"
                }
            ],
            "id": "#docm_gatk_haplotype_caller.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Adds an INFO tag (PREVIOUSLY_DISCOVERED) flagging variants in the target vcf present in a known-variants file",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bcftools-cwl:1.9"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "baseCommand": [
                "/opt/bcftools/bin/bcftools",
                "annotate"
            ],
            "arguments": [
                "-Oz",
                "-o",
                "known_variants_filtered.vcf.gz"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "valueFrom": "${\n    return [ '-a', self.path, '-m', 'PREVIOUSLY_DISCOVERED' ];\n}\n"
                    },
                    "doc": "A vcf of previously discovered variants to be marked in the second input vcf; if not provided, this tool does nothing but rename the second input vcf",
                    "id": "#filter_known_variants.cwl/known_variants"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Each variant in this file that is also in the above file (if supplied) will be marked with a PREVIOUSLY_DISCOVERED flag in its INFO field",
                    "id": "#filter_known_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "known_variants_filtered.vcf.gz"
                    },
                    "id": "#filter_known_variants.cwl/known_filtered"
                }
            ],
            "id": "#filter_known_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "cle_annotated_vcf_filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/docm_and_coding_indel_selection.pl"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.3.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "$(inputs.vcf.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "filter",
                        "position": 1
                    },
                    "id": "#filter_vcf_cle.cwl/filter"
                },
                {
                    "type": "File",
                    "id": "#filter_vcf_cle.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated_filtered.vcf"
                    },
                    "id": "#filter_vcf_cle.cwl/cle_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_cle.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Custom allele frequency filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/vep_helper-cwl:1.1.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/src/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#filter_vcf_custom_allele_freq.cwl/field_name"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "valueFrom": "${\n    return [\n        \"--filter\",\n        [\n            inputs.field_name, \"<\", inputs.maximum_population_allele_frequency,\n            \"or not\", inputs.field_name\n        ].join(\" \")\n    ]\n}\n",
                        "position": 2
                    },
                    "id": "#filter_vcf_custom_allele_freq.cwl/maximum_population_allele_frequency"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#filter_vcf_custom_allele_freq.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.af_filtered.vcf"
                    },
                    "id": "#filter_vcf_custom_allele_freq.cwl/filtered_vcf"
                }
            ],
            "id": "#filter_vcf_custom_allele_freq.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "filter variants at sites below a given sequence depth in each sample",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/depth-filter:0.1.2"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "baseCommand": [
                "/opt/conda/bin/python3",
                "/usr/bin/depth_filter.py"
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)/depth_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--minimum_depth",
                        "position": -3
                    },
                    "id": "#filter_vcf_depth.cwl/minimum_depth"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "itemSeparator": ",",
                        "position": -1
                    },
                    "id": "#filter_vcf_depth.cwl/sample_names"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#filter_vcf_depth.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "depth_filtered.vcf"
                    },
                    "id": "#filter_vcf_depth.cwl/depth_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_depth.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Filter variants from the DoCM detector",
            "baseCommand": [
                "/usr/bin/perl",
                "docm_filter.pl"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.4.2"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "docm_filter.pl",
                            "entry": "#!/usr/bin/perl\n\nuse strict;\nuse warnings;\n\nuse feature qw(say);\n\ndie(\"Wrong number of arguments. Provide docm_vcf, normal_cram, tumor_cram, output_vcf_file, set_filter_flag\") unless scalar(@ARGV) == 5;\nmy ($docm_vcf, $normal_cram, $tumor_cram, $output_vcf_file, $set_filter_flag) = @ARGV;\n\nmy $samtools = '/opt/samtools/bin/samtools';\nmy $normal_header_str = `$samtools view -H $normal_cram`;\nmy $tumor_header_str  = `$samtools view -H $tumor_cram`;\n\nmy ($normal_name) = $normal_header_str =~ /SM:([ -~]+)/;\nmy ($tumor_name)  = $tumor_header_str =~ /SM:([ -~]+)/;\n\nunless ($normal_name and $tumor_name) {\n    die \"Failed to get normal_name: $normal_name from $normal_cram AND tumor_name: $tumor_name from $tumor_cram\";\n}\n\nmy $docm_vcf_fh;\nif($docm_vcf =~ /.gz$/){\n    open($docm_vcf_fh, \"gunzip -c $docm_vcf |\") or die(\"couldn't open $docm_vcf to read\");\n} else {\n    open($docm_vcf_fh, $docm_vcf) or die(\"couldn't open $docm_vcf to read\");\n}\nopen(my $docm_out_fh, \">\", \"$output_vcf_file\") or die(\"couldn't open $output_vcf_file for write\");\n\nmy ($normal_index, $tumor_index);\n\nwhile (<$docm_vcf_fh>) {\n    chomp;\n    if (/^##/) {\n        say $docm_out_fh $_;\n    }\n    elsif (/^#CHROM/) {\n        if ($set_filter_flag) {\n            say $docm_out_fh '##FILTER=<ID=DOCM_ONLY,Description=\"ignore Docm variants\">';\n        }\n        my @columns = split /\\t/, $_;\n        my %index = (\n            $columns[9]  => 9,\n            $columns[10] => 10,\n        );\n        ($normal_index, $tumor_index) = map{$index{$_}}($normal_name, $tumor_name);\n        unless ($normal_index and $tumor_index) {\n            die \"Failed to get normal_index: $normal_index for $normal_name AND tumor_index: $tumor_index for $tumor_name\";\n        }\n        $columns[9]  = $normal_name;\n        $columns[10] = $tumor_name;\n        my $header = join \"\\t\", @columns;\n        say $docm_out_fh $header;\n    }\n    else {\n        my @columns = split /\\t/, $_;\n        my @tumor_info = split /:/, $columns[$tumor_index];\n        my ($AD, $DP) = ($tumor_info[1], $tumor_info[2]);\n        next unless $AD;\n        my @AD = split /,/, $AD;\n        shift @AD; #the first one is ref count\n        \n        for my $ad (@AD) {\n            if ($ad > 5 and $ad/$DP > 0.01) {\n                my ($normal_col, $tumor_col) = map{$columns[$_]}($normal_index, $tumor_index);\n                $columns[9]  = $normal_col;\n                $columns[10] = $tumor_col;\n                if ($set_filter_flag) {\n                    $columns[6] = 'DOCM_ONLY';\n                }\n                else {\n                    $columns[6] = '.';\n                }\n                my $new_line = join \"\\t\", @columns;\n                say $docm_out_fh $new_line;\n                last;\n            }\n        }\n    }\n}\n\nclose($docm_vcf_fh);\nclose($docm_out_fh);\n"
                        }
                    ]
                }
            ],
            "arguments": [
                "$(runtime.outdir)/docm_filtered_variants.vcf"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -4
                    },
                    "id": "#filter_vcf_docm.cwl/docm_raw_variants"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "position": 1,
                        "valueFrom": "${\n  if(inputs.filter_docm_variants){\n    return \"1\";\n  } else {\n    return \"0\";\n  }\n}\n"
                    },
                    "id": "#filter_vcf_docm.cwl/filter_docm_variants"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -3
                    },
                    "id": "#filter_vcf_docm.cwl/normal_bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#filter_vcf_docm.cwl/tumor_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "docm_filtered_variants.vcf"
                    },
                    "id": "#filter_vcf_docm.cwl/docm_filtered_variants"
                }
            ],
            "id": "#filter_vcf_docm.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "filter vcf for variants with high percentage of mapq0 reads",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/mapq0-filter:v0.3.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "tmpdirMin": 10000
                }
            ],
            "arguments": [
                "/bin/bash",
                "/usr/bin/mapq0_vcf_filter.sh",
                {
                    "valueFrom": "$(runtime.outdir)/mapq_filtered.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#filter_vcf_mapq0.cwl/reference"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#filter_vcf_mapq0.cwl/threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#filter_vcf_mapq0.cwl/tumor_bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#filter_vcf_mapq0.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mapq_filtered.vcf.gz"
                    },
                    "id": "#filter_vcf_mapq0.cwl/mapq0_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_mapq0.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "use the binomial/llr somatic filter to weed out low confidence variants",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/somatic-llr-filter:v0.4.3"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "baseCommand": [
                "/opt/conda/bin/python3",
                "/usr/bin/somatic_llr_filter.py"
            ],
            "arguments": [
                "--overwrite",
                {
                    "valueFrom": "$(runtime.outdir)/somatic_llr_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--normal-sample-name"
                    },
                    "id": "#filter_vcf_somatic_llr.cwl/normal_sample_name"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "prefix": "--llr-threshold",
                        "position": -2
                    },
                    "id": "#filter_vcf_somatic_llr.cwl/threshold"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--tumor-sample-name",
                        "position": -3
                    },
                    "id": "#filter_vcf_somatic_llr.cwl/tumor_sample_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#filter_vcf_somatic_llr.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "somatic_llr_filtered.vcf"
                    },
                    "id": "#filter_vcf_somatic_llr.cwl/somatic_llr_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_somatic_llr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "False Positive filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/fpfilter.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/fp_filter-cwl:1.0.1"
                }
            ],
            "arguments": [
                "--bam-readcount",
                "/usr/bin/bam-readcount",
                "--samtools",
                "/opt/samtools/bin/samtools",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam-file",
                        "position": 2
                    },
                    "id": "#fp_filter.cwl_2/bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05,
                    "inputBinding": {
                        "prefix": "--min-var-freq",
                        "position": 5
                    },
                    "id": "#fp_filter.cwl_2/min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "fpfilter",
                    "id": "#fp_filter.cwl_2/output_vcf_basename"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "--reference",
                        "position": 1
                    },
                    "id": "#fp_filter.cwl_2/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "TUMOR",
                    "inputBinding": {
                        "prefix": "--sample",
                        "position": 4
                    },
                    "id": "#fp_filter.cwl_2/sample_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf-file",
                        "position": 3
                    },
                    "id": "#fp_filter.cwl_2/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf"
                    },
                    "id": "#fp_filter.cwl_2/filtered_vcf"
                }
            ],
            "id": "#fp_filter.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/usr/bin/perl",
                "intervals_to_bed.pl"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:bionic"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "intervals_to_bed.pl",
                            "entry": "use feature qw(say);\n\nfor my $line (<>) {\n    chomp $line;\n\n    next if substr($line,0,1) eq '@'; #skip header lines\n\n    my ($chrom, $start, $stop) = split(/\\t/, $line);\n    say(join(\"\\t\", $chrom, $start-1, $stop));\n}\n"
                        }
                    ]
                }
            ],
            "stdout": "interval_list.bed",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#intervals_to_bed.cwl/interval_list"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#intervals_to_bed.cwl/interval_bed",
                    "outputBinding": {
                        "glob": "interval_list.bed"
                    }
                }
            ],
            "id": "#intervals_to_bed.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf merge",
            "baseCommand": [
                "/opt/bcftools/bin/bcftools",
                "concat"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bcftools-cwl:1.3.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "--allow-overlaps",
                "--remove-duplicates",
                "--output-type",
                "z",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.merged_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "merged",
                    "id": "#merge_vcf.cwl/merged_vcf_basename"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#merge_vcf.cwl/vcfs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.merged_vcf_basename).vcf.gz"
                    },
                    "id": "#merge_vcf.cwl/merged_vcf"
                }
            ],
            "id": "#merge_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Mutect2 (GATK 4)",
            "baseCommand": [
                "/bin/bash",
                "Mutect2.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 32000,
                    "tmpdirMin": 100000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.2.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "Mutect2.sh",
                            "entry": "set -o pipefail\nset -o errexit\n\nexport tumor_bam=\"$3\"\nexport normal_bam=\"$4\"\n\nTUMOR=`perl -e 'my $header_str = qx(samtools view -H $ENV{tumor_bam}); my ($sample_name) = $header_str =~ /SM:([ -~]+)/; print $sample_name'` #Extracting the sample name from the TUMOR bam.\nNORMAL=`perl -e 'my $header_str = qx(samtools view -H $ENV{normal_bam}); my ($sample_name) = $header_str =~ /SM:([ -~]+)/; print $sample_name'` #Extracting the sample name from the NORMAL bam.\n/gatk/gatk Mutect2 --java-options \"-Xmx20g\" -O $1 -R $2 -I $3 -tumor \"$TUMOR\" -I $4 -normal \"$NORMAL\" -L $5 #Running Mutect2.\n/gatk/gatk FilterMutectCalls -R $2 -V mutect.vcf.gz -O mutect.filtered.vcf.gz #Running FilterMutectCalls on the output vcf.\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "position": 1,
                    "valueFrom": "mutect.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#mutect.cwl_2/interval_list"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mutect.cwl_2/normal_bam"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#mutect.cwl_2/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mutect.cwl_2/tumor_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mutect.filtered.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl_2/vcf"
                }
            ],
            "id": "#mutect.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "Normalize variants",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "LeftAlignAndTrimVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 9000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/normalized.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#normalize_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#normalize_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "normalized.vcf.gz"
                    },
                    "id": "#normalize_variants.cwl/normalized_vcf"
                }
            ],
            "id": "#normalize_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "pindel v0.2.5b8",
            "arguments": [
                "/usr/bin/perl",
                "pindel_helper.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "tmpdirMin": 100000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.4.2"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "pindel_helper.pl",
                            "entry": "#!/usr/bin/perl\n\nuse strict;\nuse warnings;\n\nuse IO::File;\n\nunless (@ARGV > 5) {\n    die \"Usage: $0 normal.bam tumor.bam insert_size normal_sample_name tumor_sample_name <args>\";\n}\n\nmy ($normal_bam, $tumor_bam, $insert_size, $normal_name, $tumor_name, @args) = @ARGV;\n\nmy $fh = IO::File->new(\"> pindel.config\");\n\n$fh->say(join(\"\\t\", $normal_bam, $insert_size, $normal_name));\n$fh->say(join(\"\\t\", $tumor_bam, $insert_size, $tumor_name));\n$fh->close;\n\nexit system(qw(/usr/bin/pindel -i pindel.config -w 30 -T 4 -o all), @args);\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-c",
                        "position": 7
                    },
                    "id": "#pindel.cwl_2/chromosome"
                },
                {
                    "type": "int",
                    "default": 400,
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#pindel.cwl_2/insert_size"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#pindel.cwl_2/normal_bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#pindel.cwl_2/normal_sample_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 6
                    },
                    "id": "#pindel.cwl_2/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-j",
                        "position": 8
                    },
                    "id": "#pindel.cwl_2/region_file"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#pindel.cwl_2/tumor_bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#pindel.cwl_2/tumor_sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_D"
                    },
                    "id": "#pindel.cwl_2/deletions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_SI"
                    },
                    "id": "#pindel.cwl_2/insertions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_INV"
                    },
                    "id": "#pindel.cwl_2/inversions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_LI"
                    },
                    "id": "#pindel.cwl_2/long_insertions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_TD"
                    },
                    "id": "#pindel.cwl_2/tandems"
                }
            ],
            "id": "#pindel.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "pindel somatic filter v1",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/write_pindel_filter_config.pl",
                "$(inputs.pindel_output_summary.path)",
                "$(inputs.reference)",
                "$(runtime.outdir)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/perl",
                "/usr/bin/somatic_indelfilter.pl",
                "filter.config"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.3.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#pindel_somatic_filter.cwl/pindel_output_summary"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#pindel_somatic_filter.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "pindel.out.vcf"
                    },
                    "id": "#pindel_somatic_filter.cwl/vcf"
                }
            ],
            "id": "#pindel_somatic_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "remove END INFO tags",
            "baseCommand": [
                "/opt/bcftools/bin/bcftools",
                "annotate"
            ],
            "arguments": [
                "-x",
                "INFO/END",
                "-Oz",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/pindel.noend.vcf.gz"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bcftools-cwl:1.3.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#remove_end_tags.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "pindel.noend.vcf.gz"
                    },
                    "id": "#remove_end_tags.cwl/processed_vcf"
                }
            ],
            "id": "#remove_end_tags.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/bash",
                "rename_sample.sh"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bcftools-cwl:1.9"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "rename_sample.sh",
                            "entry": "#!/bin/bash\nset -eou pipefail\nbasen=`basename \"$3\"`\nbasen=\"renamed.$basen\"\n\n#escape spaces, otherwise bcftools will try to use them as a delimiter\n#triple backslash to escape within backticks and then again within sed\nold_name=`echo \"$1\" | sed 's/ /\\\\\\ /g'`\nnew_name=`echo \"$2\" | sed 's/ /\\\\\\ /g'`\n\necho \"$old_name $new_name\" > sample_update.txt\n/opt/bcftools/bin/bcftools reheader -s sample_update.txt -o \"$basen\" \"$3\"\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "vcf file to filter",
                    "id": "#replace_vcf_sample_name.cwl/input_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Sample name to replace the other",
                    "id": "#replace_vcf_sample_name.cwl/new_sample_name"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Sample name to be replaced",
                    "id": "#replace_vcf_sample_name.cwl/sample_to_replace"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(\"renamed.\" + inputs.input_vcf.basename)"
                    },
                    "id": "#replace_vcf_sample_name.cwl/renamed_vcf"
                }
            ],
            "id": "#replace_vcf_sample_name.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--excludeFiltered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--sample_name",
                        "position": 5
                    },
                    "doc": "include genotypes from this sample",
                    "id": "#select_variants.cwl/samples_to_include"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#select_variants.cwl/select_type/INDEL",
                                "#select_variants.cwl/select_type/SNP",
                                "#select_variants.cwl/select_type/MIXED",
                                "#select_variants.cwl/select_type/MNP",
                                "#select_variants.cwl/select_type/SYMBOLIC",
                                "#select_variants.cwl/select_type/NO_VARIATION"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-selectType",
                        "position": 6
                    },
                    "doc": "select only a certain type of variants",
                    "id": "#select_variants.cwl/select_type"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "create filtered VCF",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "VariantFiltration"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "--maskName",
                "processSomatic",
                "--filterNotInMask",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/output.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--mask",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#set_filter_status.cwl/filtered_vcf"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#set_filter_status.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#set_filter_status.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.vcf.gz"
                    },
                    "id": "#set_filter_status.cwl/merged_vcf"
                }
            ],
            "id": "#set_filter_status.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/usr/bin/perl",
                "split_interval_list_helper.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.3.1"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "split_interval_list_helper.pl",
                            "entry": "use File::Copy;\n\nmy $retval = system('/usr/bin/java', '-jar', '/usr/picard/picard.jar', 'IntervalListTools', @ARGV);\nexit $retval if $retval != 0;\n\nmy $i = 1;\nfor(glob('*/scattered.interval_list')) {\n    #create unique names and relocate all the scattered intervals to a single directory\n    File::Copy::move($_, qq{$i.interval_list});\n    $i++\n}\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "valueFrom": "OUTPUT=$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "separate": false,
                        "position": 1
                    },
                    "id": "#split_interval_list.cwl/interval_list"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "SCATTER_COUNT=",
                        "separate": false,
                        "position": 2
                    },
                    "id": "#split_interval_list.cwl/scatter_count"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.interval_list"
                    },
                    "id": "#split_interval_list.cwl/split_interval_lists"
                }
            ],
            "id": "#split_interval_list.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/split_interval_list_to_bed_helper.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.4.2"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "OUTPUT=$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "separate": false,
                        "position": 1
                    },
                    "id": "#split_interval_list_to_bed.cwl/interval_list"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "SCATTER_COUNT=",
                        "separate": false,
                        "position": 2
                    },
                    "id": "#split_interval_list_to_bed.cwl/scatter_count"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.interval.bed"
                    },
                    "id": "#split_interval_list_to_bed.cwl/split_beds"
                }
            ],
            "id": "#split_interval_list_to_bed.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Staged Renamer",
            "doc": "Renames a file by staging and then `mv`ing it.  A workaround for workflow engines that don't support rename.cwl.  If running in cwltool, use the other one instead.",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000,
                    "coresMin": 1
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:bionic"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "$(inputs.original)"
                    ]
                }
            ],
            "baseCommand": [
                "/bin/mv"
            ],
            "arguments": [
                "$(inputs.original.basename)",
                "$(inputs.name)"
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#staged_rename.cwl/name"
                },
                {
                    "type": "File",
                    "id": "#staged_rename.cwl/original"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.name)"
                    },
                    "id": "#staged_rename.cwl/replacement"
                }
            ],
            "id": "#staged_rename.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "strelka 2.9.9",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/docker_helper.pl"
            ],
            "requirements": [
                {
                    "dockerPull": "mgibio/strelka-cwl:2.9.9",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": 4000,
                    "class": "ResourceRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.cpu_reserved)",
                    "position": 1
                },
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": 2
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#strelka.cwl/cpu_reserved"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--exome",
                        "position": 6
                    },
                    "id": "#strelka.cwl/exome_mode"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--normalBam=",
                        "separate": false,
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#strelka.cwl/normal_bam"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "--referenceFasta=",
                        "separate": false,
                        "position": 5
                    },
                    "id": "#strelka.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--tumorBam=",
                        "separate": false,
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#strelka.cwl/tumor_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/variants/somatic.indels.vcf.gz"
                    },
                    "id": "#strelka.cwl/indels"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/variants/somatic.snvs.vcf.gz"
                    },
                    "id": "#strelka.cwl/snvs"
                }
            ],
            "id": "#strelka.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "VariantsToTable"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "--allowMissingData",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/variants.tsv"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-F"
                        }
                    },
                    "default": [
                        "CHROM",
                        "POS",
                        "ID",
                        "REF",
                        "ALT",
                        "set"
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#variants_to_table.cwl/fields"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GF"
                        }
                    },
                    "default": [
                        "GT",
                        "AD",
                        "DP",
                        "AF"
                    ],
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#variants_to_table.cwl/genotype_fields"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#variants_to_table.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#variants_to_table.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "variants.tsv"
                    },
                    "id": "#variants_to_table.cwl/variants_tsv"
                }
            ],
            "id": "#variants_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "varscan v2.4.2 processSomatic",
            "arguments": [
                "cp",
                "$(inputs.variants.path)",
                "$(runtime.outdir)/$(inputs.variants.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "java",
                "-jar",
                "/opt/varscan/VarScan.jar",
                "processSomatic"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.3.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--max-normal-freq",
                        "position": 2
                    },
                    "id": "#varscan_process_somatic.cwl/max_normal_freq"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(runtime.outdir)/$(self.basename)",
                        "position": 1
                    },
                    "id": "#varscan_process_somatic.cwl/variants"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Germline.vcf"
                    },
                    "id": "#varscan_process_somatic.cwl/germline"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Germline.hc.vcf"
                    },
                    "id": "#varscan_process_somatic.cwl/germline_hc"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.LOH.vcf"
                    },
                    "id": "#varscan_process_somatic.cwl/loh"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.LOH.hc.vcf"
                    },
                    "id": "#varscan_process_somatic.cwl/loh_hc"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Somatic.vcf"
                    },
                    "id": "#varscan_process_somatic.cwl/somatic"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Somatic.hc.vcf"
                    },
                    "id": "#varscan_process_somatic.cwl/somatic_hc"
                }
            ],
            "id": "#varscan_process_somatic.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "varscan v2.4.2 somatic",
            "baseCommand": "varscan_helper.sh",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 12000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.3.1"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "varscan_helper.sh",
                            "entry": "#!/bin/bash\n\nset -o errexit\nset -o nounset\n\nif [ $# -lt 7 ]\nthen\n    echo \"Usage: $0 [TUMOR_BAM] [NORMAL_BAM] [REFERENCE] [STRAND_FILTER] [MIN_COVERAGE] [MIN_VAR_FREQ] [P_VALUE] [roi_bed?]\"\n    exit 1\nfi\n\nTUMOR_BAM=\"$1\"\nNORMAL_BAM=\"$2\"\nREFERENCE=\"$3\"\nSTRAND_FILTER=\"$4\"\nMIN_COVERAGE=\"$5\"\nMIN_VAR_FREQ=\"$6\"\nP_VALUE=\"$7\"\nOUTPUT=\"${HOME}/output\"\n\nif [ -z ${8+x} ]\nthen\n    #run without ROI\n    java -jar /opt/varscan/VarScan.jar somatic \\\n        <(/opt/samtools/bin/samtools mpileup --no-baq -f \"$REFERENCE\" \"$NORMAL_BAM\" \"$TUMOR_BAM\") \\\n        $OUTPUT \\\n        --strand-filter $STRAND_FILTER \\\n        --min-coverage $MIN_COVERAGE \\\n        --min-var-freq $MIN_VAR_FREQ \\\n        --p-value $P_VALUE \\\n        --mpileup 1 \\\n        --output-vcf\nelse\n    ROI_BED=\"$8\"\n    java -jar /opt/varscan/VarScan.jar somatic \\\n        <(/opt/samtools/bin/samtools mpileup --no-baq -l \"$ROI_BED\" -f \"$REFERENCE\" \"$NORMAL_BAM\" \"$TUMOR_BAM\") \\\n        $OUTPUT \\\n        --strand-filter $STRAND_FILTER \\\n        --min-coverage $MIN_COVERAGE \\\n        --min-var-freq $MIN_VAR_FREQ \\\n        --p-value $P_VALUE \\\n        --mpileup 1 \\\n        --output-vcf\nfi\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#varscan_somatic.cwl/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "inputBinding": {
                        "position": 6
                    },
                    "id": "#varscan_somatic.cwl/min_var_freq"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#varscan_somatic.cwl/normal_bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#varscan_somatic.cwl/p_value"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#varscan_somatic.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#varscan_somatic.cwl/roi_bed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#varscan_somatic.cwl/strand_filter"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#varscan_somatic.cwl/tumor_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.indel.vcf"
                    },
                    "id": "#varscan_somatic.cwl/indels"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.snp.vcf"
                    },
                    "id": "#varscan_somatic.cwl/snvs"
                }
            ],
            "id": "#varscan_somatic.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add bam_readcount info to vcf",
            "baseCommand": [
                "vcf-readcount-annotator"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "griffithlab/vatools:3.1.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.bam_readcount.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/bam_readcount_tsv"
                },
                {
                    "type": [
                        {
                            "type": "enum",
                            "symbols": [
                                "#vcf_readcount_annotator.cwl_2/data_type/DNA",
                                "#vcf_readcount_annotator.cwl_2/data_type/RNA"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/data_type"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/sample_name"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#vcf_readcount_annotator.cwl_2/variant_type/snv",
                                "#vcf_readcount_annotator.cwl_2/variant_type/indel",
                                "#vcf_readcount_annotator.cwl_2/variant_type/all"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/variant_type"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.bam_readcount.vcf.gz"
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/annotated_bam_readcount_vcf"
                }
            ],
            "id": "#vcf_readcount_annotator.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "Sanitize a VCF",
            "baseCommand": [
                "/bin/bash",
                "sanitize.sh"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000,
                    "coresMin": 1
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "sanitize.sh",
                            "entry": "set -eou pipefail\n\n# 1) removes lines containing non ACTGN bases, as they conflict with the VCF spec\n# and cause GATK to choke\n# 2) removes mutect-specific format tags containing underscores, which are likewise\n# illegal in the vcf spec\nbase=`basename $1`\noutbase=`echo $base | perl -pe 's/.vcf(.gz)?$//g'`\necho \"$1   $base    $outbase\"\nif [[ \"$1\" =~ \".gz\" ]];then\n    #gzipped input\n    gunzip -c \"$1\" | perl -a -F'\\t' -ne 'print $_ if $_ =~ /^#/ || $F[3] !~ /[^ACTGNactgn]/' | sed -e \"s/ALT_F1R2/ALTF1R2/g;s/ALT_F2R1/ALTF2R1/g;s/REF_F1R2/REFF1R2/g;s/REF_F2R1/REFF2R1/g\" >$outbase.sanitized.vcf\nelse\n    #non-gzipped input\n    cat \"$1\" | perl -a -F'\\t' -ne 'print $_ if $_ =~ /^#/ || $F[3] !~ /[^ACTGNactgn]/' | sed -e \"s/ALT_F1R2/ALTF1R2/g;s/ALT_F2R1/ALTF2R1/g;s/REF_F1R2/REFF1R2/g;s/REF_F2R1/REFF2R1/g\" >$outbase.sanitized.vcf\nfi\n/opt/htslib/bin/bgzip $outbase.sanitized.vcf\n/usr/bin/tabix -p vcf $outbase.sanitized.vcf.gz\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#vcf_sanitize.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if(inputs.vcf.nameext === \".gz\"){\n    return inputs.vcf.nameroot.replace(/.vcf$/, \"\") + \".sanitized.vcf.gz\";\n  }\n  return inputs.vcf.nameroot + \".sanitized.vcf.gz\";\n}\n"
                    },
                    "id": "#vcf_sanitize.cwl/sanitized_vcf"
                }
            ],
            "id": "#vcf_sanitize.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Ensembl Variant Effect Predictor",
            "baseCommand": [
                "/usr/bin/perl",
                "-I",
                "/opt/lib/perl/VEP/Plugins",
                "/usr/bin/variant_effect_predictor.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#vep_custom_annotation.yml/vep_custom_annotation"
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 4,
                    "ramMin": 64000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/vep_helper-cwl:1.1.0"
                }
            ],
            "arguments": [
                "--format",
                "vcf",
                "--vcf",
                "--fork",
                "4",
                "--term",
                "SO",
                "--transcript_version",
                "--offline",
                "--cache",
                "--symbol",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.vcf.nameroot)_annotated.vcf"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "string",
                        "Directory"
                    ],
                    "inputBinding": {
                        "prefix": "--dir",
                        "position": 4
                    },
                    "id": "#vep.cwl/cache_dir"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--coding_only",
                        "position": 3
                    },
                    "default": false,
                    "id": "#vep.cwl/coding_only"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "#vep_custom_annotation.yml/vep_custom_annotation",
                            "label": "custom type, check types directory for input format",
                            "inputBinding": {
                                "valueFrom": "${\n    return [self.annotation.check_existing ? '--check_existing' : '',\n      '--custom',\n      [self.annotation.file.path,\n      self.annotation.name,\n      self.annotation.data_format,\n      self.method,\n      self.force_report_coordinates ? 1 : 0,\n      self.annotation.vcf_fields ? self.annotation.vcf_fields : ''\n      ].filter(String).join(',')\n    ].filter(String)\n}\n",
                                "position": 6
                            }
                        }
                    ],
                    "id": "#vep.cwl/custom_annotations"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--assembly",
                        "position": 10
                    },
                    "doc": "genome assembly to use in vep. Examples: 'GRCh38' or 'GRCm38'",
                    "id": "#vep.cwl/ensembl_assembly"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--species",
                        "position": 12
                    },
                    "doc": "ensembl species - Must be present in the cache directory. Examples: 'homo_sapiens' or 'mus_musculus'",
                    "id": "#vep.cwl/ensembl_species"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--cache_version",
                        "position": 11
                    },
                    "doc": "ensembl version - Must be present in the cache directory. Example: '95'",
                    "id": "#vep.cwl/ensembl_version"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--everything",
                        "position": 9
                    },
                    "id": "#vep.cwl/everything"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#vep.cwl/pick/pick",
                                "#vep.cwl/pick/flag_pick",
                                "#vep.cwl/pick/pick_allele",
                                "#vep.cwl/pick/per_gene",
                                "#vep.cwl/pick/pick_allele_gene",
                                "#vep.cwl/pick/flag_pick_allele",
                                "#vep.cwl/pick/flag_pick_allele_gene"
                            ]
                        }
                    ],
                    "default": "flag_pick",
                    "inputBinding": {
                        "prefix": "--",
                        "separate": false,
                        "position": 7
                    },
                    "id": "#vep.cwl/pick"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "--plugin"
                        }
                    },
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#vep.cwl/plugins"
                },
                {
                    "type": [
                        "null",
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "--fasta",
                        "position": 7
                    },
                    "id": "#vep.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--synonyms",
                        "position": 2
                    },
                    "id": "#vep.cwl/synonyms_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#vep.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.vcf.nameroot)_annotated.vcf"
                    },
                    "id": "#vep.cwl/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.vcf.nameroot)_annotated.vcf_summary.html"
                    },
                    "id": "#vep.cwl/vep_summary"
                }
            ],
            "id": "#vep.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "run vt decompose",
            "baseCommand": [
                "vt",
                "decompose"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/vt:0.57721--hf74b74d_1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-s",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/decomposed.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#vt_decompose.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "decomposed.vcf.gz"
                    },
                    "id": "#vt_decompose.cwl/decomposed_vcf"
                }
            ],
            "id": "#vt_decompose.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
